/* This stylesheet is generated, DO NOT EDIT */
/* Copyright 2009, 2015 Red Hat, Inc.
 *
 * Portions adapted from Mx's data/style/default.css
 *   Copyright 2009 Intel Corporation
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms and conditions of the GNU Lesser General Public License,
 * version 2.1, as published by the Free Software Foundation.
 *
 * This program is distributed in the hope it will be useful, but WITHOUT ANY
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for
 * more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St - Fifth Floor, Boston, MA 02110-1301 USA.
 */
/* Global Values */
stage {
  font-size: 11pt;
  color: #dddddd;
}

/* Common Stylings */
.search-statustext {
  font-size: 2em;
  font-weight: bold;
  color: #efefef;
}

.workspace-switcher-container, .switcher-list, .resize-popup, .osd-window {
  color: #efefef;
  background-color: #22242d;
  border-radius: 5px;
  padding: 12px;
  border: 1px solid rgba(0, 0, 0, 0.75);
}

.workspace-thumbnails .workspace-thumbnail {
  color: #efefef;
  background-color: rgba(239, 239, 239, 0.1);
}

.app-well-app.app-folder .overview-icon, .app-well-app .overview-icon,
.grid-search-result .overview-icon, .dash-item-container .show-apps .overview-icon, .list-search-result, .search-provider-icon {
  border-radius: 3px;
  padding: 6px;
  border: 2px solid transparent;
  transition-duration: 100ms;
  text-align: center;
}

.modal-dialog {
  color: #dddddd;
  background-color: #1b1d24;
  box-shadow: none;
  border-radius: 5px;
  border: 1px solid rgba(0, 0, 0, 0.75);
}

.quick-settings-system-item .icon-button, .icon-button, .background-app-item .close-button, .button {
  border-radius: 3px;
  padding: 3px 24px;
  font-weight: bold;
  transition: border-width 300ms cubic-bezier(0.25, 0.46, 0.45, 0.94), box-shadow 300ms cubic-bezier(0.25, 0.46, 0.45, 0.94);
}

.icon-button, .background-app-item .close-button, .button {
  color: #dddddd;
  background-color: #22242d;
  border-color: #101115;
  box-shadow: none;
  text-shadow: none;
  icon-shadow: none;
}

.icon-button:focus, .background-app-item .close-button:focus, .button:focus {
  color: #dddddd;
  text-shadow: none;
  icon-shadow: none;
  box-shadow: inset 0 0 0 2px rgba(33, 125, 187, 0.35) !important;
}

.icon-button:hover, .background-app-item .close-button:hover, .button:hover {
  color: #dddddd;
  background-color: #2b2d36;
  border-color: #101115;
  box-shadow: none;
  text-shadow: none;
  icon-shadow: none;
}

.icon-button:insensitive, .background-app-item .close-button:insensitive, .button:insensitive {
  color: #66686e;
  border-color: #14161b;
  background-color: #22242d;
  box-shadow: none;
  text-shadow: none;
  icon-shadow: none;
}

.icon-button:selected, .background-app-item .close-button:selected, .button:selected, .icon-button:active, .background-app-item .close-button:active, .button:active {
  color: #dddddd;
  background-color: #34373e;
  border-color: #101115;
  text-shadow: none;
  icon-shadow: none;
  box-shadow: none;
}

.icon-button:checked, .background-app-item .close-button:checked, .button:checked {
  color: #dddddd;
  background-color: #2b2d36;
  border-color: #101115;
  text-shadow: none;
  icon-shadow: none;
  box-shadow: none;
}

.quick-settings-system-item .icon-button, .quick-settings-system-item .background-app-item .close-button, .background-app-item .quick-settings-system-item .close-button {
  color: #dddddd;
  background-color: rgba(221, 221, 221, 0.03);
  border-color: #101115;
  box-shadow: none;
  text-shadow: none;
  icon-shadow: none;
}

.quick-settings-system-item .icon-button:focus, .quick-settings-system-item .background-app-item .close-button:focus, .background-app-item .quick-settings-system-item .close-button:focus {
  color: #dddddd;
  text-shadow: none;
  icon-shadow: none;
  box-shadow: inset 0 0 0 2px rgba(33, 125, 187, 0.35) !important;
}

.quick-settings-system-item .icon-button:hover, .quick-settings-system-item .background-app-item .close-button:hover, .background-app-item .quick-settings-system-item .close-button:hover {
  color: #dddddd;
  background-color: #2b2d36;
  border-color: #101115;
  box-shadow: none;
  text-shadow: none;
  icon-shadow: none;
}

.quick-settings-system-item .icon-button:insensitive, .quick-settings-system-item .background-app-item .close-button:insensitive, .background-app-item .quick-settings-system-item .close-button:insensitive {
  color: #66686e;
  border-color: #14161b;
  background-color: #22242d;
  box-shadow: none;
  text-shadow: none;
  icon-shadow: none;
}

.quick-settings-system-item .icon-button:selected, .quick-settings-system-item .background-app-item .close-button:selected, .background-app-item .quick-settings-system-item .close-button:selected, .quick-settings-system-item .icon-button:active, .quick-settings-system-item .background-app-item .close-button:active, .background-app-item .quick-settings-system-item .close-button:active {
  color: #dddddd;
  background-color: #34373e;
  border-color: #101115;
  text-shadow: none;
  icon-shadow: none;
  box-shadow: none;
}

.quick-settings-system-item .icon-button:checked, .quick-settings-system-item .background-app-item .close-button:checked, .background-app-item .quick-settings-system-item .close-button:checked {
  color: #dddddd;
  background-color: #2b2d36;
  border-color: #101115;
  text-shadow: none;
  icon-shadow: none;
  box-shadow: none;
}

.icon-button.flat, .background-app-item .flat.close-button, .popup-menu .button, .button.flat {
  color: #dddddd;
  background-color: transparent;
  border-color: transparent;
  text-shadow: none;
  icon-shadow: none;
}

.icon-button.flat:focus, .background-app-item .flat.close-button:focus, .popup-menu .button:focus, .button.flat:focus {
  color: #dddddd;
  text-shadow: none;
  icon-shadow: none;
  box-shadow: inset 0 0 0 2px rgba(33, 125, 187, 0.6);
}

.icon-button.flat:hover, .background-app-item .flat.close-button:hover, .popup-menu .button:hover, .button.flat:hover {
  color: #dddddd;
  background-color: rgba(221, 221, 221, 0.08);
  border-color: transparent;
  text-shadow: none;
  icon-shadow: none;
}

.icon-button.flat:insensitive, .background-app-item .flat.close-button:insensitive, .popup-menu .button:insensitive, .button.flat:insensitive {
  color: #66686e;
  border-color: transparent;
  background-color: rgba(221, 221, 221, 0.01);
  box-shadow: none;
  text-shadow: none;
  icon-shadow: none;
}

.icon-button.flat:selected, .background-app-item .flat.close-button:selected, .popup-menu .button:selected, .button.flat:selected, .icon-button.flat:active, .background-app-item .flat.close-button:active, .popup-menu .button:active, .button.flat:active {
  color: #dddddd;
  background-color: rgba(221, 221, 221, 0.15);
  border-color: transparent;
  text-shadow: none;
  icon-shadow: none;
  box-shadow: none;
}

.icon-button.flat:checked, .background-app-item .flat.close-button:checked, .popup-menu .button:checked, .button.flat:checked {
  color: #dddddd;
  background-color: rgba(221, 221, 221, 0.12);
  border-color: transparent;
  text-shadow: none;
  icon-shadow: none;
  box-shadow: none;
}

.keyboard-brightness-level .button:checked, .icon-button.default, .background-app-item .default.close-button, .button.default {
  color: #ffffff;
  background-color: #217dbb;
  border-color: #101115;
  box-shadow: none;
  text-shadow: none;
  icon-shadow: none;
}

.keyboard-brightness-level .button:focus:checked, .icon-button.default:focus, .background-app-item .default.close-button:focus, .button.default:focus {
  color: #ffffff;
  text-shadow: none;
  icon-shadow: none;
  box-shadow: inset 0 0 0 2px rgba(33, 125, 187, 0.35) !important;
}

.keyboard-brightness-level .button:hover:checked, .icon-button.default:hover, .background-app-item .default.close-button:hover, .button.default:hover {
  color: #ffffff;
  background-color: #2c84be;
  border-color: #101115;
  box-shadow: none;
  text-shadow: none;
  icon-shadow: none;
}

.keyboard-brightness-level .button:insensitive:checked, .icon-button.default:insensitive, .background-app-item .default.close-button:insensitive, .button.default:insensitive {
  color: #66686e;
  border-color: #14161b;
  background-color: #22242d;
  box-shadow: none;
  text-shadow: none;
  icon-shadow: none;
}

.keyboard-brightness-level .button:active:checked, .icon-button.default:active, .background-app-item .default.close-button:active, .button.default:active {
  color: #ffffff;
  background-color: #378ac2;
  border-color: #101115;
  text-shadow: none;
  icon-shadow: none;
  box-shadow: none;
}

.modal-dialog .modal-dialog-linked-button, .hotplug-notification-item, .notification-banner .notification-button {
  color: #dddddd;
  background-color: #22242d;
  border-color: #101115;
  box-shadow: none;
  text-shadow: none;
  icon-shadow: none;
  padding: 12px !important;
  border: none !important;
  border-top: 1px solid #101115 !important;
  border-left: 1px solid #101115 !important;
}

.modal-dialog .modal-dialog-linked-button:insensitive, .hotplug-notification-item:insensitive, .notification-banner .notification-button:insensitive {
  color: #66686e;
  border-color: #14161b;
  background-color: #22242d;
  box-shadow: none;
  text-shadow: none;
  icon-shadow: none;
}

.modal-dialog .modal-dialog-linked-button:hover, .hotplug-notification-item:hover, .notification-banner .notification-button:hover {
  color: #dddddd;
  background-color: #2b2d36;
  border-color: #101115;
  box-shadow: none;
  text-shadow: none;
  icon-shadow: none;
}

.modal-dialog .modal-dialog-linked-button:focus, .hotplug-notification-item:focus, .notification-banner .notification-button:focus {
  color: #dddddd;
  text-shadow: none;
  icon-shadow: none;
  box-shadow: inset 0 0 0 2px rgba(33, 125, 187, 0.35) !important;
}

.modal-dialog .modal-dialog-linked-button:active, .hotplug-notification-item:active, .notification-banner .notification-button:active {
  color: #dddddd;
  background-color: #34373e;
  border-color: #101115;
  text-shadow: none;
  icon-shadow: none;
  box-shadow: none;
}

.modal-dialog .modal-dialog-linked-button:checked, .hotplug-notification-item:checked, .notification-banner .notification-button:checked {
  color: #dddddd;
  background-color: #2b2d36;
  border-color: #101115;
  text-shadow: none;
  icon-shadow: none;
  box-shadow: none;
}

.modal-dialog .modal-dialog-linked-button:first-child:ltr, .hotplug-notification-item:first-child:ltr, .notification-banner .notification-button:first-child:ltr {
  border-left: none !important;
  border-radius: 0 0 0 5px;
}

.modal-dialog .modal-dialog-linked-button:last-child:ltr, .hotplug-notification-item:last-child:ltr, .notification-banner .notification-button:last-child:ltr {
  border-radius: 0 0 5px 0;
  margin-right: 0 !important;
  color: #217dbb !important;
}

.modal-dialog .modal-dialog-linked-button:last-child:ltr:insensitive, .hotplug-notification-item:last-child:ltr:insensitive, .notification-banner .notification-button:last-child:ltr:insensitive {
  color: rgba(33, 125, 187, 0.35) !important;
}

.modal-dialog .modal-dialog-linked-button:first-child:rtl, .hotplug-notification-item:first-child:rtl, .notification-banner .notification-button:first-child:rtl {
  border-radius: 0 0 5px 0;
  color: #217dbb !important;
}

.modal-dialog .modal-dialog-linked-button:first-child:rtl:insensitive, .hotplug-notification-item:first-child:rtl:insensitive, .notification-banner .notification-button:first-child:rtl:insensitive {
  color: rgba(33, 125, 187, 0.35) !important;
}

.modal-dialog .modal-dialog-linked-button:last-child:rtl, .hotplug-notification-item:last-child:rtl, .notification-banner .notification-button:last-child:rtl {
  border-radius: 0 0 0 5px;
  margin-left: 0 !important;
}

.modal-dialog .modal-dialog-linked-button:first-child:last-child, .hotplug-notification-item:first-child:last-child, .notification-banner .notification-button:first-child:last-child {
  border-radius: 0 0 5px 5px;
  margin-left: 0 !important;
  margin-right: 0 !important;
  border-left: none !important;
}

.popup-menu-content, .candidate-popup-content {
  background-color: #1b1d24 !important;
  border-radius: 3px;
  box-shadow: 0 2px 6px rgba(0, 0, 0, 0.15);
  border: solid #101115;
  border-width: 1px;
}

/* General Typography */
.message-list .message-list-placeholder, .datemenu-today-button .date-label {
  font-weight: 800;
  font-size: 15pt;
}

.quick-toggle-menu .header .title {
  font-weight: 700;
  font-size: 15pt;
}

.bt-menu-placeholder.popup-menu-item {
  font-weight: 700;
  font-size: 13pt;
}

.background-app-item .title, .message-list-controls, .weather-button .weather-forecast-temp, .weather-button .weather-header, .world-clocks-button .world-clocks-time, .world-clocks-button .world-clocks-header, .events-button .events-title, .calendar .calendar-month-header .calendar-month-label, .datemenu-today-button .day-label, .popup-menu-ornament {
  font-weight: 700;
  font-size: 11pt;
}

.quick-toggle-menu .header .subtitle, .app-menu .popup-inactive-menu-item:first-child > StLabel {
  font-weight: 700;
  font-size: 9pt;
}

.background-app-item .subtitle, .weather-button .weather-forecast-time, .world-clocks-button .world-clocks-timezone, .events-button .event-time {
  font-weight: 400;
  font-size: 9pt;
}

.calendar .calendar-day.calendar-day-heading,
.calendar .calendar-day-base.calendar-day-heading, .calendar .calendar-day,
.calendar .calendar-day-base {
  font-weight: 400;
  font-size: 8pt;
}

.weather-button .weather-forecast-time, .world-clocks-button .world-clocks-timezone, .world-clocks-button .world-clocks-time, .events-button .event-time, .calendar .calendar-day,
.calendar .calendar-day-base {
  font-feature-settings: "tnum";
}

/* WIDGETS */
.shell-link {
  color: #5faee3;
}

.shell-link:hover {
  color: #8bc4ea;
}

.lowres-icon {
  icon-shadow: 0 1px 2px rgba(0, 0, 0, 0.25);
}

.icon-dropshadow {
  icon-shadow: 0 2px 5px rgba(0, 0, 0, 0.35);
}

/* Entries */
.prompt-dialog-password-grid .prompt-dialog-password-entry,
StEntry {
  border-radius: 3px;
  padding: 8px;
  border-width: 1px;
  color: #dddddd;
  background-color: #1b1d24;
  border: 1px solid #101115 !important;
  box-shadow: none !important;
  selection-background-color: #217dbb !important;
  selected-color: #ffffff !important;
}

.prompt-dialog-password-grid .prompt-dialog-password-entry:focus,
StEntry:focus {
  background-color: #1b1d24;
  border: 1px solid #217dbb !important;
  box-shadow: none !important;
}

.prompt-dialog-password-grid .prompt-dialog-password-entry:insensitive,
StEntry:insensitive {
  color: #66686e;
  border: 1px solid #22242d !important;
  box-shadow: none !important;
}

.prompt-dialog-password-grid .prompt-dialog-password-entry StIcon.capslock-warning,
StEntry StIcon.capslock-warning {
  icon-size: 16px;
  warning-color: #f57900;
  padding: 0 4px;
}

.prompt-dialog-password-grid .prompt-dialog-password-entry StIcon.peek-password,
StEntry StIcon.peek-password {
  icon-size: 16px;
  padding: 0 4px;
}

.prompt-dialog-password-grid .prompt-dialog-password-entry StLabel.hint-text,
StEntry StLabel.hint-text {
  margin-left: 2px;
  color: rgba(221, 221, 221, 0.7);
}

/* Buttons */
.button {
  min-height: 1.5em;
}

.icon-button, .background-app-item .close-button {
  border-radius: 1000px;
  padding: 0.818em;
  min-height: 1.091em;
}

.icon-button StIcon, .background-app-item .close-button StIcon {
  icon-size: 1.091em;
  -st-icon-style: symbolic;
}

/* Check Boxes */
.check-box StBoxLayout {
  spacing: .8em;
}

.check-box StBin {
  width: 24px;
  height: 24px;
  background-image: url("assets/checkbox-off.svg");
}

.check-box:focus StBin {
  background-image: url("assets/checkbox-off.svg");
}

.check-box:checked StBin {
  background-image: url("assets/checkbox.svg");
}

.check-box:focus:checked StBin {
  background-image: url("assets/checkbox.svg");
}

/* Switches */
.toggle-switch {
  color: #dddddd;
  height: 24px;
  width: 52px;
  background-size: contain;
  background-image: url("assets/toggle-off.svg");
}

.toggle-switch:checked {
  background-image: url("assets/toggle-on.svg");
}

.popup-menu-item:hover .toggle-switch, .popup-menu-item:selected .toggle-switch {
  background-image: url("assets/toggle-off.svg");
}

.popup-menu-item:hover .toggle-switch:checked, .popup-menu-item:selected .toggle-switch:checked {
  background-image: url("assets/toggle-on.svg");
  box-shadow: inset 0 0 0 100px rgba(255, 255, 255, 0.35);
}

/* Slider */
.slider {
  height: 20px;
  color: #282b35;
  -barlevel-height: 4px;
  -barlevel-background-color: #101115;
  -barlevel-border-width: 0;
  -barlevel-border-color: #101115;
  -barlevel-active-background-color: #217dbb;
  -barlevel-active-border-color: #2383c4;
  -barlevel-overdrive-color: #b2161d;
  -barlevel-overdrive-border-color: #bc171e;
  -barlevel-overdrive-separator-width: 1px;
  -slider-handle-radius: 9px;
  -slider-handle-border-width: 1px;
  -slider-handle-border-color: rgba(0, 0, 0, 0.45);
}

.popup-menu-item.selected .slider, .popup-menu-item:hover .slider, .popup-menu-item:focus .slider {
  color: #ffffff;
  -slider-background-color: rgba(0, 0, 0, 0.2);
  -slider-active-background-color: #ffffff;
  -slider-handle-border-color: rgba(0, 0, 0, 0.2);
  -barlevel-background-color: rgba(0, 0, 0, 0.2);
  -barlevel-active-background-color: #ffffff;
  -barlevel-border-color: rgba(0, 0, 0, 0.2);
}

/* Scrollbars */
StScrollView.vfade {
  -st-vfade-offset: 68px;
}

StScrollView.hfade {
  -st-hfade-offset: 68px;
}

StScrollBar {
  padding: 0;
  margin: 6px;
}

StScrollView StScrollBar {
  min-width: 6px;
  min-height: 6px;
}

StScrollBar StBin#trough {
  border-radius: 8px;
  background-color: rgba(221, 221, 221, 0.1);
}

StScrollBar StButton#vhandle, StScrollBar StButton#hhandle {
  border-radius: 8px;
  background-color: #949599;
  border: 3px solid transparent;
}

StScrollBar StButton#vhandle:hover, StScrollBar StButton#hhandle:hover {
  background-color: #b8b9bb;
}

StScrollBar StButton#vhandle:active, StScrollBar StButton#hhandle:active {
  background-color: #217dbb;
}

#overviewGroup StScrollBar StBin#trough {
  background-color: rgba(239, 239, 239, 0.1);
}

#overviewGroup StScrollBar StButton#vhandle, #overviewGroup StScrollBar StButton#hhandle {
  background-color: #9d9ea1;
}

#overviewGroup StScrollBar StButton#vhandle:hover, #overviewGroup StScrollBar StButton#hhandle:hover {
  background-color: #c6c6c8;
}

#overviewGroup StScrollBar StButton#vhandle:active, #overviewGroup StScrollBar StButton#hhandle:active {
  background-color: #217dbb;
}

/* Popovers/Menus */
.popup-menu-boxpointer, .candidate-popup-boxpointer {
  -arrow-border-radius: 5px;
  -arrow-background-color: transparent;
  -arrow-border-width: 0;
  -arrow-border-color: transparent;
  -arrow-base: 12px;
  -arrow-rise: 6px;
  -arrow-box-shadow: none;
}

.popup-menu {
  min-width: 15em;
  color: #dddddd;
  padding: 0;
  background: none;
  border-image: none;
  font-size: 10pt;
}

.popup-menu.panel-menu {
  -boxpointer-gap: 4px;
  margin-bottom: 1.75em;
}

.popup-menu .search-entry {
  color: #aaaaaa;
  caret-color: #aaaaaa;
  background-color: rgba(221, 221, 221, 0.1);
  border-color: #101115;
}

.popup-menu .search-entry:hover {
  background-color: rgba(221, 221, 221, 0.15);
  border-color: #101115;
  color: #dddddd;
}

.popup-menu .search-entry:focus, .popup-menu .search-entry:focus:hover {
  background-color: rgba(221, 221, 221, 0.15);
  color: #dddddd;
  border-color: #217dbb;
}

.popup-menu .search-entry StLabel.hint-text {
  color: #66686e;
}

.popup-menu-content, .candidate-popup-content {
  padding: 6px 0;
  margin: 0 4px 10px 8px;
  color: #dddddd !important;
}

.popup-menu-item {
  spacing: 6px;
  padding: 6px 12px;
  margin: 0;
  border-radius: 0 !important;
  color: #aaaaaa !important;
}

.popup-menu-item:checked {
  box-shadow: inset 0 1px #101115 !important;
  border: none;
  border-image: none;
  background-color: rgba(0, 0, 0, 0.15) !important;
  color: #dddddd !important;
}

.popup-menu-item.selected, .popup-menu-item:hover, .popup-menu-item:focus {
  color: #ffffff !important;
  background-color: #217dbb !important;
  border-image: none;
}

.popup-menu-item:active {
  background-color: #1d6fa5 !important;
  color: #ffffff !important;
}

.popup-menu-item:insensitive {
  color: #66686e !important;
}

.popup-menu-item .toggle-switch:ltr {
  margin-left: 4px;
}

.popup-menu-item .toggle-switch:rtl {
  margin-right: 4px;
}

.popup-inactive-menu-item {
  color: #dddddd;
}

.popup-inactive-menu-item:insensitive {
  color: #66686e;
}

.popup-menu-arrow,
.popup-menu-icon {
  icon-size: 16px !important;
}

.popup-sub-menu {
  background-color: rgba(0, 0, 0, 0.15) !important;
  border-image: none;
  box-shadow: inset 0 -1px #101115 !important;
  border: none;
  border-radius: 0 !important;
  margin: 0;
}

.popup-sub-menu .popup-menu-ornament {
  min-width: 16px !important;
}

.popup-sub-menu .popup-menu-item {
  border-radius: 0 !important;
  border-top-width: 0;
  background-color: transparent;
}

.popup-sub-menu .popup-menu-item:last-child {
  border-radius: 0 !important;
  border-bottom-width: 0;
}

.popup-sub-menu .popup-menu-section .popup-menu-item:last-child:hover, .popup-sub-menu .popup-menu-section .popup-menu-item:last-child:focus {
  border-radius: 0 !important;
}

.popup-sub-menu .popup-menu-section:last-child .popup-menu-item:last-child {
  border-radius: 0 !important;
}

.popup-menu-ornament {
  width: 1.2em;
  text-align: center !important;
}

.popup-menu-ornament:ltr {
  text-align: right;
}

.popup-menu-ornament:rtl {
  text-align: left;
}

.popup-separator-menu-item {
  border: none !important;
  padding: 6px 0 !important;
}

.popup-separator-menu-item .popup-separator-menu-item-separator {
  height: 1px;
  background-color: #101115;
}

.popup-separator-menu-item .popup-menu-ornament {
  width: 0 !important;
}

.popup-sub-menu .popup-separator-menu-item {
  background-color: transparent;
}

.popup-sub-menu .popup-separator-menu-item:ltr {
  margin-right: 2.5em;
}

.popup-sub-menu .popup-separator-menu-item:rtl {
  margin-left: 2.5em;
}

.popup-sub-menu .popup-separator-menu-item .popup-separator-menu-item-separator {
  background-color: #101115;
}

.background-menu {
  -boxpointer-gap: 4px;
  -arrow-rise: 0px;
}

.aggregate-menu {
  min-width: 21em;
}

.aggregate-menu .popup-menu-icon {
  padding: 0;
  margin: 0 4px;
  -st-icon-style: symbolic;
}

.aggregate-menu .popup-menu-item > :first-child:ltr {
  padding-left: 0 !important;
  margin-left: 0 !important;
}

.aggregate-menu .popup-menu-item > :first-child:rtl {
  padding-right: 0 !important;
  margin-right: 0 !important;
}

.aggregate-menu .popup-sub-menu .popup-menu-item > :first-child:ltr {
  padding-left: 12px !important;
  margin-left: 3px !important;
}

.aggregate-menu .popup-sub-menu .popup-menu-item > :first-child:rtl {
  padding-right: 12px !important;
  margin-right: 3px !important;
}

.system-menu-action {
  color: #aaaaaa;
  border-radius: 1000px;
  padding: 12px;
  border: none;
  -st-icon-style: symbolic;
}

.system-menu-action:hover, .system-menu-action:focus {
  background-color: rgba(221, 221, 221, 0.1);
  color: #dddddd;
  border: none;
  padding: 12px;
}

.system-menu-action:active {
  background-color: rgba(221, 221, 221, 0.15);
  color: #dddddd;
}

.system-menu-action > StIcon {
  icon-size: 16px;
}

.app-menu {
  max-width: 27.25em;
}

.app-menu .popup-menu-ornament {
  width: 0 !important;
}

.app-menu .popup-inactive-menu-item:first-child > StLabel:ltr {
  margin-right: 8px;
}

.app-menu .popup-inactive-menu-item:first-child > StLabel:rtl {
  margin-left: 8px;
}

/* Date/Time Menu */
#calendarArea {
  padding: 2px 8px;
}

.datemenu-calendar-column {
  spacing: 6px;
}

.datemenu-calendar-column:ltr {
  padding-left: 6px;
}

.datemenu-calendar-column:rtl {
  padding-right: 6px;
}

.datemenu-calendar-column .datemenu-displays-box {
  spacing: 6px;
}

/* today button (the date) */
.datemenu-today-button {
  border-radius: 3px;
  margin: 4px;
  border-color: transparent;
  background-color: transparent;
  background-image: none;
  box-shadow: inset 0 1px rgba(255, 255, 255, 0), 0 1px rgba(221, 221, 221, 0);
  text-shadow: none;
  icon-shadow: none;
  color: #dddddd;
  box-shadow: none !important;
  padding: 9px;
}

.datemenu-today-button:hover {
  color: #dddddd;
  background-color: #2b2d36;
  border-color: #101115;
  box-shadow: none;
  text-shadow: none;
  icon-shadow: none;
}

.datemenu-today-button:active {
  color: #dddddd;
  background-color: #34373e;
  border-color: #101115;
  text-shadow: none;
  icon-shadow: none;
  box-shadow: none;
}

.datemenu-today-button:focus {
  color: #dddddd;
  text-shadow: none;
  icon-shadow: none;
  box-shadow: inset 0 0 0 2px rgba(33, 125, 187, 0.35) !important;
}

.datemenu-today-button .day-label {
  color: #aaaaaa;
}

/* Calendar */
.calendar {
  border-radius: 3px;
  margin: 4px;
  border-color: transparent;
  background-color: transparent;
  background-image: none;
  box-shadow: inset 0 1px rgba(255, 255, 255, 0), 0 1px rgba(221, 221, 221, 0);
  text-shadow: none;
  icon-shadow: none;
  color: #dddddd;
  box-shadow: none !important;
  margin-top: 0;
}

.calendar:hover {
  color: #dddddd;
  background-color: #2b2d36;
  border-color: #101115;
  box-shadow: none;
  text-shadow: none;
  icon-shadow: none;
}

.calendar:active {
  color: #dddddd;
  background-color: #34373e;
  border-color: #101115;
  text-shadow: none;
  icon-shadow: none;
  box-shadow: none;
}

.calendar:focus {
  color: #dddddd;
  text-shadow: none;
  icon-shadow: none;
  box-shadow: inset 0 0 0 2px rgba(33, 125, 187, 0.35) !important;
}

.calendar .calendar-month-header .calendar-change-month-back,
.calendar .calendar-month-header .calendar-change-month-forward {
  padding: 2px;
}

.calendar .calendar-month-header .calendar-change-month-back StIcon,
.calendar .calendar-month-header .calendar-change-month-forward StIcon {
  icon-size: 16px;
}

.calendar .calendar-month-header .calendar-month-label {
  padding: 8px 0;
}

.calendar .calendar-month-header .pager-button {
  background-color: transparent;
  height: 32px;
  width: 32px;
  margin: 2px;
  border-radius: 1000px;
}

.calendar .calendar-month-header .pager-button:hover, .calendar .calendar-month-header .pager-button:focus {
  color: #dddddd;
  background-color: rgba(221, 221, 221, 0.08);
  border-color: transparent;
  text-shadow: none;
  icon-shadow: none;
}

.calendar .calendar-month-header .pager-button:active {
  color: #dddddd;
  background-color: rgba(221, 221, 221, 0.15);
  border-color: transparent;
  text-shadow: none;
  icon-shadow: none;
  box-shadow: none;
}

.calendar .calendar-day,
.calendar .calendar-day-base {
  text-align: center;
  margin: 2px;
  padding: 0 !important;
  height: 3em !important;
  width: 3em !important;
  border-radius: 1000px;
  transition-duration: 100ms;
  color: #aaaaaa;
}

.calendar .calendar-day:hover, .calendar .calendar-day:focus,
.calendar .calendar-day-base:hover,
.calendar .calendar-day-base:focus {
  background-color: rgba(221, 221, 221, 0.1);
  box-shadow: none !important;
  color: #dddddd;
}

.calendar .calendar-day:active, .calendar .calendar-day:selected,
.calendar .calendar-day-base:active,
.calendar .calendar-day-base:selected {
  color: #dddddd;
  background-color: rgba(221, 221, 221, 0.15);
  box-shadow: none !important;
}

.calendar .calendar-day.calendar-day-heading,
.calendar .calendar-day-base.calendar-day-heading {
  color: #66686e;
  padding-top: 6px;
  height: 16px !important;
  font-weight: 600;
}

.calendar .calendar-day {
  font-weight: 600;
}

.calendar .calendar-day.calendar-weekend {
  color: #66686e;
}

.calendar .calendar-day.calendar-other-month {
  color: rgba(102, 104, 110, 0.75) !important;
  font-weight: normal;
}

.calendar .calendar-nonwork-day {
  color: #66686e;
}

.calendar .calendar-other-month-day {
  color: rgba(221, 221, 221, 0.5);
}

.calendar .calendar-other-month-day.calendar-nonwork-day {
  color: rgba(102, 104, 110, 0.5);
}

.calendar .calendar-today {
  background-color: #217dbb;
  font-weight: 800;
  color: #ffffff !important;
}

.calendar .calendar-today:hover, .calendar .calendar-today:focus {
  background-color: #2386c8;
  color: inherit;
  box-shadow: none !important;
}

.calendar .calendar-today:active, .calendar .calendar-today:selected {
  background-color: #217dbb;
  color: inherit;
  box-shadow: none !important;
}

.calendar .calendar-today:active:hover, .calendar .calendar-today:active:focus, .calendar .calendar-today:selected:hover, .calendar .calendar-today:selected:focus {
  background-color: #2386c8;
  color: inherit;
}

.calendar .calendar-day-with-events {
  background-image: url("resource:///org/gnome/shell/theme/calendar-today.svg");
  background-size: contain;
}

.calendar .calendar-week-number {
  font-size: 7pt;
  font-weight: bold;
  font-feature-settings: "tnum";
  margin: 6px;
  padding: 0 6px;
  border-radius: 3px;
  background-color: rgba(221, 221, 221, 0.1);
  color: #66686e;
}

/* Events */
.events-button {
  border-radius: 3px;
  margin: 4px;
  color: #dddddd;
  background-color: #22242d;
  border-color: #101115;
  box-shadow: none;
  text-shadow: none;
  icon-shadow: none;
  box-shadow: 0 1px 1px 0 rgba(0, 0, 0, 0.05);
  padding: 12px;
}

.events-button:hover {
  color: #dddddd;
  background-color: #2b2d36;
  border-color: #101115;
  box-shadow: none;
  text-shadow: none;
  icon-shadow: none;
}

.events-button:active {
  color: #dddddd;
  background-color: #34373e;
  border-color: #101115;
  text-shadow: none;
  icon-shadow: none;
  box-shadow: none;
}

.events-button:focus {
  color: #dddddd;
  text-shadow: none;
  icon-shadow: none;
  box-shadow: inset 0 0 0 2px rgba(33, 125, 187, 0.35) !important;
}

.events-button .events-box {
  spacing: 6px;
}

.events-button .events-list {
  spacing: 12px;
  color: #dddddd;
}

.events-button .events-title {
  color: #66686e;
  margin-bottom: 4px;
}

.events-button .event-time {
  color: #66686e;
}

/* World clocks */
.world-clocks-button {
  border-radius: 3px;
  margin: 4px;
  color: #dddddd;
  background-color: #22242d;
  border-color: #101115;
  box-shadow: none;
  text-shadow: none;
  icon-shadow: none;
  box-shadow: 0 1px 1px 0 rgba(0, 0, 0, 0.05);
  padding: 12px;
}

.world-clocks-button:hover {
  color: #dddddd;
  background-color: #2b2d36;
  border-color: #101115;
  box-shadow: none;
  text-shadow: none;
  icon-shadow: none;
}

.world-clocks-button:active {
  color: #dddddd;
  background-color: #34373e;
  border-color: #101115;
  text-shadow: none;
  icon-shadow: none;
  box-shadow: none;
}

.world-clocks-button:focus {
  color: #dddddd;
  text-shadow: none;
  icon-shadow: none;
  box-shadow: inset 0 0 0 2px rgba(33, 125, 187, 0.35) !important;
}

.world-clocks-button .world-clocks-grid {
  spacing-rows: 6px;
  spacing-columns: 12px;
}

.world-clocks-button .world-clocks-header {
  color: #66686e;
}

.world-clocks-button .world-clocks-city {
  color: #dddddd;
}

.world-clocks-button .world-clocks-time {
  color: #dddddd;
}

.world-clocks-button .world-clocks-time:ltr {
  text-align: right;
}

.world-clocks-button .world-clocks-time:rtl {
  text-align: left;
}

.world-clocks-button .world-clocks-timezone {
  color: #66686e;
}

/* Weather */
.weather-button {
  border-radius: 3px;
  margin: 4px;
  color: #dddddd;
  background-color: #22242d;
  border-color: #101115;
  box-shadow: none;
  text-shadow: none;
  icon-shadow: none;
  box-shadow: 0 1px 1px 0 rgba(0, 0, 0, 0.05);
  padding: 12px;
}

.weather-button:hover {
  color: #dddddd;
  background-color: #2b2d36;
  border-color: #101115;
  box-shadow: none;
  text-shadow: none;
  icon-shadow: none;
}

.weather-button:active {
  color: #dddddd;
  background-color: #34373e;
  border-color: #101115;
  text-shadow: none;
  icon-shadow: none;
  box-shadow: none;
}

.weather-button:focus {
  color: #dddddd;
  text-shadow: none;
  icon-shadow: none;
  box-shadow: inset 0 0 0 2px rgba(33, 125, 187, 0.35) !important;
}

.weather-button .weather-box {
  spacing: 10px;
}

.weather-button .weather-header-box {
  spacing: 6px;
}

.weather-button .weather-header {
  color: #66686e;
}

.weather-button .weather-header.location {
  font-weight: normal;
}

.weather-button .weather-grid {
  spacing-rows: 6px;
  spacing-columns: 12px;
}

.weather-button .weather-forecast-time {
  color: #aaaaaa;
  padding-top: 0.2em;
  padding-bottom: 0.4em;
}

.weather-button .weather-forecast-icon {
  icon-size: 32px;
}

/* Message List */
.message-list {
  width: 29em;
  border: solid #101115;
}

.message-list:ltr {
  margin-left: 0;
  margin-right: 4px;
  padding-right: 6px;
  border-right-width: 1px;
}

.message-list:rtl {
  margin-right: 0;
  margin-left: 4px;
  padding-left: 6px;
  border-left-width: 1px;
}

.message-list .message-list-placeholder {
  color: rgba(102, 104, 110, 0.5);
}

.message-list .message-list-placeholder > StIcon {
  icon-size: 48px;
  margin-bottom: 12px;
  -st-icon-style: symbolic;
}

.message-list-sections {
  spacing: 6px;
  margin: 0;
  padding-bottom: 6px;
}

.message-list-sections:ltr {
  margin-right: 4px;
}

.message-list-sections:rtl {
  margin-left: 4px;
}

.message-list-section,
.message-list-section-list {
  spacing: 6px;
}

.message-list-controls {
  padding: 6px;
  spacing: 6px;
}

.message-list-controls .dnd-button {
  border-width: 2px;
  border-color: transparent;
  border-radius: 32px;
  border-style: solid;
}

.message-list-controls .dnd-button:focus {
  border-color: rgba(33, 125, 187, 0.6);
}

.message {
  border-radius: 3px;
  margin: 4px;
  color: #dddddd;
  background-color: #22242d;
  border-color: #101115;
  box-shadow: none;
  text-shadow: none;
  icon-shadow: none;
  box-shadow: 0 1px 1px 0 rgba(0, 0, 0, 0.05);
}

.message:hover {
  color: #dddddd;
  background-color: #2b2d36;
  border-color: #101115;
  box-shadow: none;
  text-shadow: none;
  icon-shadow: none;
}

.message:active {
  color: #dddddd;
  background-color: #34373e;
  border-color: #101115;
  text-shadow: none;
  icon-shadow: none;
  box-shadow: none;
}

.message:focus {
  color: #dddddd;
  text-shadow: none;
  icon-shadow: none;
  box-shadow: inset 0 0 0 2px rgba(33, 125, 187, 0.35) !important;
}

.message .message-icon-bin {
  padding: 18px;
}

.message .message-icon-bin:ltr {
  padding-right: 6px;
}

.message .message-icon-bin:rtl {
  padding-left: 6px;
}

.message .message-icon-bin > StIcon {
  icon-size: 32px;
  -st-icon-style: symbolic;
}

.message .message-icon-bin > .fallback-app-icon {
  width: 16px;
  height: 16px;
}

.message .message-content {
  spacing: 4px;
  padding: 9px;
  margin-bottom: 8px;
}

.message .message-title {
  font-weight: bold;
  /* HACK: the label should be baseline-aligned with a 1em label, fake this with some bottom padding */
  padding-top: 0.57em;
}

.message .message-secondary-bin {
  padding: 0 8px;
}

.message .message-secondary-bin > .event-time {
  color: rgba(221, 221, 221, 0.5);
  font-size: 9pt;
  /* HACK: the label should be baseline-aligned with a 1em label, fake this with some bottom padding */
  padding-bottom: 0.13em;
}

.message .message-secondary-bin > .event-time:ltr {
  text-align: right;
}

.message .message-secondary-bin > .event-time:rtl {
  text-align: left;
}

.message .message-close-button {
  color: #dddddd;
  background-color: rgba(221, 221, 221, 0.1);
  border-radius: 99px;
  padding: 5px;
  margin: 1px;
}

.message .message-close-button:hover {
  background-color: rgba(221, 221, 221, 0.2);
}

.message .message-close-button:active {
  background-color: rgba(221, 221, 221, 0.1);
}

.message .message-close-button StIcon {
  icon-size: 16px;
}

.message .message-body {
  color: #c4c4c4;
}

.url-highlighter {
  link-color: #5faee3;
}

/* Media Controls */
.message-media-control {
  padding: 0 18px;
  margin: 18px 0;
  border-radius: 3px;
  color: #dddddd;
}

.message-media-control:hover {
  background-color: rgba(221, 221, 221, 0.08);
  color: #dddddd;
}

.message-media-control:active {
  background-color: rgba(221, 221, 221, 0.12);
  color: #dddddd;
}

.message-media-control:insensitive {
  color: #72757b;
}

.message-media-control:last-child:ltr {
  margin-right: 12px;
}

.message-media-control:last-child:rtl {
  margin-left: 12px;
}

.message-media-control StIcon {
  icon-size: 16px;
}

.media-message-cover-icon {
  icon-size: 48px !important;
  border-radius: 3px;
  padding: 0;
}

.media-message-cover-icon.fallback {
  color: rgba(221, 221, 221, 0.75);
  background-color: rgba(221, 221, 221, 0.08);
  border: none;
  border-radius: 3px;
  icon-size: 32px !important;
  padding: 9px;
}

.candidate-popup-content {
  padding: 0.5em;
  spacing: 0.3em;
}

.candidate-index {
  padding: 0 0.5em 0 0;
  color: #aaaaaa;
}

.candidate-box:selected .candidate-index {
  color: #ffffff;
}

.candidate-box {
  padding: 0.3em 0.5em 0.3em 0.5em;
  border-radius: 3px;
  margin-right: 2px;
}

.candidate-box:last-child {
  margin-right: 0;
}

.candidate-box:hover {
  background-color: rgba(221, 221, 221, 0.1);
  color: #dddddd;
}

.candidate-box:active {
  background-color: rgba(221, 221, 221, 0.15);
  color: #dddddd;
}

.candidate-box:selected {
  background-color: #217dbb;
  color: #ffffff;
}

.candidate-page-button-box {
  height: 2em;
}

.vertical .candidate-page-button-box {
  padding-top: 0.5em;
}

.horizontal .candidate-page-button-box {
  padding-left: 0.5em;
}

.candidate-page-button {
  padding: 4px;
}

.candidate-page-button-previous {
  border-radius: 3px 0px 0px 3px;
  border-right-width: 0;
}

.candidate-page-button-next {
  border-radius: 0px 3px 3px 0px;
}

.candidate-page-button-icon {
  icon-size: 1em;
}

.quick-settings {
  padding: 12px !important;
  border-radius: 5px !important;
  margin-top: 6px !important;
}

.quick-settings .icon-button, .quick-settings .background-app-item .close-button, .background-app-item .quick-settings .close-button, .quick-settings .button {
  min-height: 20px;
  min-width: 20px;
  padding: 10.5px;
}

.quick-settings .icon-button StIcon, .quick-settings .background-app-item .close-button StIcon, .background-app-item .quick-settings .close-button StIcon, .quick-settings .button StIcon {
  icon-size: 16px !important;
}

.quick-settings .icon-button, .quick-settings .background-app-item .close-button, .background-app-item .quick-settings .close-button {
  border-radius: 1000px;
  border: none;
}

.quick-settings-grid {
  spacing-rows: 12px;
  spacing-columns: 12px;
}

.quick-toggle, .quick-menu-toggle {
  border-radius: 3px;
  min-width: 12em;
  max-width: 12em;
  min-height: 40px;
  border: none;
}

.quick-toggle {
  background-color: rgba(221, 221, 221, 0.06) !important;
  color: #aaaaaa;
  text-shadow: none !important;
  /* Move padding into the box; this is to allow menu arrows
     to extend to the border */
}

.quick-toggle:hover {
  background-color: rgba(221, 221, 221, 0.12) !important;
  color: #dddddd;
}

.quick-toggle:active {
  background-color: rgba(221, 221, 221, 0.18) !important;
  color: #dddddd;
}

.quick-toggle:checked {
  background-color: #217dbb !important;
  color: #ffffff !important;
  text-shadow: none !important;
}

.quick-toggle:checked:hover {
  background-color: #258cd1 !important;
  color: #ffffff !important;
  text-shadow: none !important;
}

.quick-toggle:checked:active {
  background-color: #1d6fa5 !important;
  color: #ffffff !important;
}

.quick-toggle > StBoxLayout {
  spacing: 6px;
}

.quick-toggle.button {
  padding: 0;
  min-height: 40px;
}

.quick-toggle > StBoxLayout {
  padding: 0 12px;
}

.quick-toggle:ltr > StBoxLayout {
  padding-left: 15px;
}

.quick-toggle:rtl > StBoxLayout {
  padding-right: 15px;
}

.quick-toggle .quick-toggle-title {
  font-weight: bold;
}

.quick-toggle StBoxLayout > .quick-toggle-subtitle {
  font-weight: normal;
  font-size: 12px;
}

.quick-toggle .quick-toggle-icon {
  icon-size: 16px;
}

.quick-menu-toggle .quick-toggle {
  min-width: auto;
  max-width: auto;
}

.quick-menu-toggle .quick-toggle:ltr {
  border-radius: 3px 0 0 3px;
}

.quick-menu-toggle .quick-toggle:ltr > StBoxLayout {
  padding-right: 9px;
}

.quick-menu-toggle .quick-toggle:rtl {
  border-radius: 0 3px 3px 0;
}

.quick-menu-toggle .quick-toggle:rtr > StBoxLayout {
  padding-left: 9px;
}

.quick-menu-toggle .quick-toggle:ltr:last-child {
  border-radius: 3px;
}

.quick-menu-toggle .quick-toggle:rtl:last-child {
  border-radius: 3px;
}

.quick-menu-toggle .quick-toggle-arrow {
  background-color: rgba(221, 221, 221, 0.1) !important;
  color: #aaaaaa;
  text-shadow: none !important;
}

.quick-menu-toggle .quick-toggle-arrow:hover {
  background-color: rgba(221, 221, 221, 0.18) !important;
  color: #dddddd;
}

.quick-menu-toggle .quick-toggle-arrow:active {
  background-color: rgba(221, 221, 221, 0.26) !important;
  color: #dddddd;
}

.quick-menu-toggle .quick-toggle-arrow:checked {
  background-color: #217dbb !important;
  color: #ffffff;
  text-shadow: none !important;
}

.quick-menu-toggle .quick-toggle-arrow:checked:hover {
  background-color: #258cd1 !important;
  color: #ffffff;
  text-shadow: none !important;
}

.quick-menu-toggle .quick-toggle-arrow:checked:active {
  background-color: #1d6fa5 !important;
  color: #ffffff;
}

.quick-menu-toggle .quick-toggle-arrow:ltr {
  border-radius: 0 3px 3px 0;
  border-left-width: 0;
}

.quick-menu-toggle .quick-toggle-arrow:rtl {
  border-radius: 3px 0 0 3px;
  border-right-width: 0;
}

.quick-slider {
  padding: 0 6px;
}

.quick-slider > StBoxLayout {
  spacing: 6px;
}

.quick-slider .slider-bin {
  min-height: 16px;
  padding: 6px;
  border-radius: 99px;
}

.quick-slider .slider-bin:focus {
  color: #dddddd;
  text-shadow: none;
  icon-shadow: none;
  box-shadow: inset 0 0 0 2px rgba(33, 125, 187, 0.35) !important;
}

.quick-slider .quick-toggle-icon {
  icon-size: 16px;
}

.quick-slider .icon-button, .quick-slider .background-app-item .close-button, .background-app-item .quick-slider .close-button {
  background-color: transparent;
  color: #dddddd !important;
  padding: 6px;
}

.quick-slider .icon-button:hover, .quick-slider .background-app-item .close-button:hover, .background-app-item .quick-slider .close-button:hover {
  background-color: rgba(221, 221, 221, 0.06);
}

.quick-slider .icon-button:active, .quick-slider .background-app-item .close-button:active, .background-app-item .quick-slider .close-button:active {
  background-color: rgba(221, 221, 221, 0.12);
}

.quick-toggle-menu {
  background-color: #1b1d24 !important;
  color: #dddddd !important;
  border-radius: 5px !important;
  padding: 12px 0 !important;
  margin: 12px 18px 0 21px !important;
}

.quick-toggle-menu .popup-menu-item {
  border-radius: 0 !important;
}

.quick-toggle-menu .popup-menu-item > StIcon {
  -st-icon-style: symbolic;
}

.quick-toggle-menu .header {
  spacing-rows: 3px;
  spacing-columns: 12px;
  padding: 0 12px 12px !important;
}

.quick-toggle-menu .header .icon {
  icon-size: 24px;
  border-radius: 1000px;
  padding: 9px;
  background-color: rgba(221, 221, 221, 0.12) !important;
}

.quick-toggle-menu .header .icon.active {
  background-color: #217dbb !important;
  color: #ffffff;
}

.quick-settings-system-item > StBoxLayout {
  spacing: 12px;
}

.quick-settings-system-item .icon-button > StIcon, .quick-settings-system-item .background-app-item .close-button > StIcon, .background-app-item .quick-settings-system-item .close-button > StIcon {
  -st-icon-style: symbolic;
  icon-size: 16px !important;
}

.quick-settings-system-item .power-item {
  min-height: 0;
  min-width: 0;
}

.quick-settings-system-item .power-item:insensitive {
  color: #dddddd;
  background-color: #22242d;
  border-color: #101115;
  box-shadow: none;
  text-shadow: none;
  icon-shadow: none;
  background-color: transparent;
}

.nm-network-item .wireless-secure-icon {
  icon-size: 8px;
}

.bt-device-item .popup-menu-icon {
  -st-icon-style: symbolic;
}

.bt-menu-placeholder.popup-menu-item {
  text-align: center;
  padding: 2em 4em;
}

.device-subtitle {
  color: rgba(221, 221, 221, 0.5);
}

.keyboard-brightness-level {
  spacing: 6px;
}

.background-apps-quick-toggle {
  min-height: 40px;
  background-color: transparent;
}

.background-apps-quick-toggle StIcon {
  icon-size: 16px !important;
}

.background-app-item .popup-menu-icon {
  icon-size: 32px !important;
  -st-icon-style: regular !important;
}

.background-app-item .close-button {
  padding: 6px;
}

.background-app-item.popup-inactive-menu-item {
  color: #dddddd;
}

/* Notifications & Message Tray */
.notification-banner {
  min-height: 64px;
  width: 34em;
  margin: 6px;
  border-radius: 5px;
  border: none;
  box-shadow: 0 3px 6px rgba(0, 0, 0, 0.15);
}

.notification-banner, .notification-banner:hover, .notification-banner:focus {
  color: #dddddd;
  background-color: #1b1d24;
}

.notification-banner .notification-icon {
  padding: 5px;
}

.notification-banner .notification-content {
  padding: 5px;
  spacing: 5px;
}

.notification-banner .secondary-icon {
  icon-size: 16px;
}

.notification-banner .notification-actions {
  spacing: 0;
}

.summary-source-counter {
  font-size: 10pt;
  font-weight: bold;
  height: 1.6em;
  width: 1.6em;
  -shell-counter-overlap-x: 3px;
  -shell-counter-overlap-y: 3px;
  background-color: #217dbb;
  color: #ffffff;
  border: 2px solid #dddddd;
  box-shadow: 0 2px 2px rgba(0, 0, 0, 0.5);
  border-radius: 0.9em;
}

.chat-body {
  spacing: 5px;
}

.chat-response {
  margin: 5px;
}

.chat-log-message {
  color: #c4c4c4;
}

.chat-new-group {
  padding-top: 1em;
}

.chat-received {
  padding-left: 4px;
}

.chat-received:rtl {
  padding-left: 0px;
  padding-right: 4px;
}

.chat-sent {
  padding-left: 18pt;
  color: white;
}

.chat-sent:rtl {
  padding-left: 0;
  padding-right: 18pt;
}

.chat-meta-message {
  padding-left: 4px;
  font-size: 9pt;
  font-weight: bold;
  color: white;
}

.chat-meta-message:rtl {
  padding-left: 0;
  padding-right: 4px;
}

.hotplug-notification-item-icon {
  icon-size: 24px;
  padding: 0 4px;
}

/* Modal Dialogs */
.headline {
  font-size: 12pt;
}

.modal-dialog {
  padding: 0 !important;
}

.modal-dialog .modal-dialog-content-box {
  margin: 32px 40px;
  spacing: 32px;
  max-width: 28em;
}

/* End Session Dialog */
.end-session-dialog {
  width: 30em;
}

.end-session-dialog .end-session-dialog-battery-warning,
.end-session-dialog .dialog-list-title {
  color: #f57900;
}

/* Message Dialog */
.message-dialog-content {
  spacing: 18px;
}

.message-dialog-content .message-dialog-title {
  text-align: center;
  font-size: 18pt;
  font-weight: 800;
}

.message-dialog-content .message-dialog-title.lightweight {
  font-size: 13pt;
  font-weight: 800;
}

.message-dialog-content .message-dialog-description {
  text-align: center;
}

/* Dialog List */
.dialog-list {
  spacing: 18px;
}

.dialog-list .dialog-list-title {
  text-align: center;
  font-weight: bold;
}

.dialog-list .dialog-list-scrollview {
  max-height: 200px;
}

.dialog-list .dialog-list-box {
  spacing: 1em;
}

.dialog-list .dialog-list-box .dialog-list-item {
  spacing: 1em;
}

.dialog-list .dialog-list-box .dialog-list-item .dialog-list-item-title {
  font-weight: bold;
}

.dialog-list .dialog-list-box .dialog-list-item .dialog-list-item-description {
  color: #d0d0d0;
  font-size: 10pt;
}

/* Run Dialog */
.run-dialog .modal-dialog-content-box {
  margin-top: 24px;
  margin-bottom: 14px;
}

.run-dialog .run-dialog-entry {
  width: 20em;
}

.run-dialog .run-dialog-description {
  font-size: 10pt;
  text-align: center;
  color: #aaaaaa;
}

/* Password or Authentication Dialog */
.prompt-dialog {
  width: 28em;
}

.prompt-dialog .modal-dialog-content-box {
  margin-bottom: 24px;
}

.prompt-dialog-password-grid {
  spacing-rows: 8px;
  spacing-columns: 4px;
}

.prompt-dialog-password-grid .prompt-dialog-password-entry {
  width: auto;
}

.prompt-dialog-password-grid .prompt-dialog-password-entry:ltr {
  margin-left: 20px;
}

.prompt-dialog-password-grid .prompt-dialog-password-entry:rtl {
  margin-right: 20px;
}

.prompt-dialog-password-layout {
  spacing: 8px;
}

.prompt-dialog-error-label,
.prompt-dialog-info-label,
.prompt-dialog-null-label {
  text-align: center;
  font-size: 10pt;
}

.prompt-dialog-error-label {
  color: #f57900;
}

/* Polkit Dialog */
.polkit-dialog-user-layout {
  text-align: center;
  spacing: 8px;
  margin-bottom: 6px;
}

.polkit-dialog-user-layout .polkit-dialog-user-root-label {
  color: #f57900;
}

/* Audio selection dialog */
.audio-device-selection-dialog .modal-dialog-content-box {
  margin-bottom: 28px;
}

.audio-device-selection-dialog .audio-selection-box {
  spacing: 20px;
}

.audio-selection-device {
  border: 1px solid rgba(0, 0, 0, 0.25);
  border-radius: 12px;
}

.audio-selection-device:hover, .audio-selection-device:focus {
  background-color: rgba(221, 221, 221, 0.08);
}

.audio-selection-device:active {
  background-color: #217dbb;
  color: #ffffff;
}

.audio-selection-device-box {
  padding: 20px;
  spacing: 20px;
}

.audio-selection-device-icon {
  icon-size: 64px;
}

/* Welcome dialog */
.welcome-dialog-image {
  background-image: url("resource:///org/gnome/shell/theme/gnome-shell-start.svg");
  background-size: contain;
  /* Reasonable maximum dimensions */
  height: 300px;
  width: 300px;
}

/* Network Dialogs */
.nm-dialog {
  max-height: 34em;
  min-height: 31em;
  min-width: 32em;
}

.nm-dialog-content {
  spacing: 20px;
  padding: 24px;
}

.nm-dialog-airplane-box {
  spacing: 12px;
}

.nm-dialog-airplane-headline {
  font-weight: bold;
  text-align: center;
}

.nm-dialog-airplane-text {
  color: #dddddd;
}

.nm-dialog-header {
  font-weight: bold;
}

.nm-dialog-header-icon {
  icon-size: 32px;
}

.nm-dialog-header-hbox {
  spacing: 10px;
}

.nm-dialog-scroll-view {
  border: 1px solid #101115;
  padding: 0;
  background-color: #1f222a;
}

.nm-dialog-item {
  font-size: 11pt;
  border-bottom: 1px solid #101115;
  padding: 12px;
  spacing: 0px;
}

.nm-dialog-item:selected {
  background-color: #217dbb;
  color: #ffffff;
}

.nm-dialog-icon {
  icon-size: 16px;
}

.nm-dialog-icons {
  spacing: 12px;
}

.no-networks-label {
  color: #66686e;
}

.no-networks-box {
  spacing: 6px;
}

/* OSD */
.osd-window {
  font-weight: 700;
  font-size: 11pt;
  text-align: center;
  font-weight: bold;
  spacing: 12px;
  padding: 18px 24px;
  margin-bottom: 4em;
}

.osd-window > * {
  spacing: 8px;
}

.osd-window StIcon {
  icon-size: 32px;
}

.osd-window .osd-monitor-label {
  font-size: 3em;
}

.osd-window StLabel:ltr {
  margin-right: 6px;
}

.osd-window StLabel:rtl {
  margin-left: 6px;
}

.osd-window .level {
  margin-bottom: 4px;
  height: 8px;
  min-width: 160px;
  -barlevel-height: 8px;
  -barlevel-background-color: rgba(239, 239, 239, 0.1);
  -barlevel-active-background-color: #217dbb;
  -barlevel-overdrive-color: #b2161d;
  -barlevel-overdrive-separator-width: 3px;
}

.osd-window .level:first-child {
  margin-bottom: 0px;
}

.osd-window .level:ltr {
  margin-right: 6px;
}

.osd-window .level:rtl {
  margin-left: 6px;
}

/* Pad OSD */
.pad-osd-window {
  padding: 32px;
  background-color: rgba(0, 0, 0, 0.8);
}

.pad-osd-window .pad-osd-title-box {
  spacing: 12px;
}

.pad-osd-window .pad-osd-title-menu-box {
  spacing: 6px;
}

.combo-box-label {
  width: 15em;
}

/* App Switcher */
.switcher-popup {
  padding: 8px;
  spacing: 24px;
}

.switcher-list {
  border-radius: 9px;
}

.switcher-list .item-box {
  padding: 8px;
  border-radius: 3px;
  border: 1px solid transparent;
  background-color: transparent;
}

.switcher-list .item-box:outlined {
  background-color: rgba(239, 239, 239, 0.3);
}

.switcher-list .item-box:selected {
  background-color: #217dbb;
  color: #ffffff;
}

.switcher-list .thumbnail-box {
  padding: 2px;
  spacing: 6px;
}

.switcher-list .thumbnail {
  width: 256px;
}

.switcher-list .separator {
  width: 1px;
  background: #101115;
}

.switcher-list .switcher-list-item-container {
  spacing: 12px;
}

.switcher-arrow {
  border-color: rgba(0, 0, 0, 0);
  color: rgba(221, 221, 221, 0.8);
}

.switcher-arrow:highlighted {
  color: #dddddd;
}

.input-source-switcher-symbol {
  font-size: 34pt;
  width: 96px;
  height: 96px;
}

.cycler-highlight {
  border: 5px solid #217dbb;
}

/* Workspace Switcher */
.workspace-switcher-group {
  padding: 12px;
}

.workspace-switcher {
  background: transparent;
  border: none;
  border-radius: 3px;
  padding: 0;
  spacing: 12px;
}

.ws-switcher-box {
  background: transparent;
  height: 50px;
  background-size: 32px;
  border: 1px solid rgba(239, 239, 239, 0.1);
  border-radius: 3px;
}

.ws-switcher-active-up,
.ws-switcher-active-down,
.ws-switcher-active-left,
.ws-switcher-active-right {
  height: 52px;
  background-color: #217dbb;
  border: 1px solid #258cd1;
  border-radius: 3px;
  color: #ffffff;
}

/* Top Bar */
#panel {
  background-color: #0c0d10;
  font-weight: bold;
  height: 2.2em;
  font-feature-settings: "tnum";
  transition-duration: 250ms;
  font-size: 10pt;
}

#panel.unlock-screen, #panel.login-screen, #panel:overview {
  background-color: transparent;
}

#panel.unlock-screen .panel-corner, #panel.login-screen .panel-corner, #panel:overview .panel-corner {
  -panel-corner-opacity: 0;
}

#panel .panel-corner {
  -panel-corner-radius: 0;
  -panel-corner-background-color: #0c0d10;
  -panel-corner-border-width: 2px;
  -panel-corner-border-color: transparent;
  -panel-corner-opacity: 1;
  transition-duration: 250ms;
}

#panel .panel-button {
  font-weight: bold;
  color: #dddddd;
  -natural-hpadding: 12px;
  -minimum-hpadding: 12px;
  transition-duration: 150ms;
  border: none;
  border-bottom: 3px solid transparent;
  border-radius: 0;
  text-shadow: none;
}

#panel .panel-button.clock-display {
  border: none;
  border-bottom: 3px solid transparent !important;
}

#panel .panel-button.clock-display .clock {
  transition-duration: 150ms;
  border: 0 none transparent;
  border-radius: 0;
}

#panel .panel-button.clock-display:active, #panel .panel-button.clock-display:overview, #panel .panel-button.clock-display:checked, #panel .panel-button.clock-display:focus {
  background-color: rgba(255, 255, 255, 0.15) !important;
  border-color: #217dbb !important;
  box-shadow: none !important;
}

#panel .panel-button:hover, #panel .panel-button:active, #panel .panel-button:overview, #panel .panel-button:focus, #panel .panel-button:checked {
  border-image: none;
}

#panel .panel-button:hover {
  background-color: rgba(255, 255, 255, 0.08);
  box-shadow: none;
}

#panel .panel-button:active, #panel .panel-button:overview, #panel .panel-button:checked, #panel .panel-button:focus {
  background-color: rgba(255, 255, 255, 0.15);
  border-color: #217dbb;
  box-shadow: none !important;
  text-shadow: none;
}

#panel .panel-button .system-status-icon {
  icon-size: 16px;
  padding: 6px;
  margin: 0;
}

#panel .panel-button .app-menu-icon {
  -st-icon-style: symbolic;
}

#panel .panel-button#panelActivities {
  -natural-hpadding: 18px;
}

#panel .panel-button#panelActivities StBoxLayout {
  spacing: 5px;
}

#panel .panel-button#panelActivities .workspace-dot {
  border-radius: 999px;
  min-width: 8px;
  min-height: 8px;
  background-color: #dddddd;
}

#panel Gjs_status_keyboard_InputSourceIndicator.panel-button,
#panel Gjs_appindicatorsupport_rgcjonas_gmail_com_indicatorStatusIcon_AppIndicatorsIndicatorStatusIcon.panel-button {
  -natural-hpadding: 18px !important;
  -minimum-hpadding: 18px !important;
}

#panel.unlock-screen .panel-button:hover.clock-display .clock, #panel.unlock-screen .panel-button:active.clock-display .clock, #panel.unlock-screen .panel-button:overview.clock-display .clock, #panel.unlock-screen .panel-button:focus.clock-display .clock, #panel.unlock-screen .panel-button:checked.clock-display .clock, #panel.login-screen .panel-button:hover.clock-display .clock, #panel.login-screen .panel-button:active.clock-display .clock, #panel.login-screen .panel-button:overview.clock-display .clock, #panel.login-screen .panel-button:focus.clock-display .clock, #panel.login-screen .panel-button:checked.clock-display .clock, #panel:overview .panel-button:hover.clock-display .clock, #panel:overview .panel-button:active.clock-display .clock, #panel:overview .panel-button:overview.clock-display .clock, #panel:overview .panel-button:focus.clock-display .clock, #panel:overview .panel-button:checked.clock-display .clock {
  box-shadow: none !important;
  border: none !important;
}

#panel .screencast-indicator,
#panel .remote-access-indicator {
  color: #f57900;
}

#appMenu {
  spacing: 6px;
}

#appMenu .label-shadow {
  color: transparent;
}

#appMenu .panel-status-menu-box {
  padding: 0 6px;
  spacing: 6px;
}

/* Activities Ripple */
.ripple-box {
  background-color: rgba(182, 218, 242, 0.3);
  box-shadow: 0 0 2px 2px #5faee3;
  width: 52px;
  height: 52px;
  border-radius: 0 0 52px 0;
}

.ripple-box:rtl {
  border-radius: 0 0 0 52px;
}

/* OVERVIEW */
.controls-manager, .secondary-monitor-workspaces {
  spacing: 12px;
}

#overviewGroup {
  background-color: #17181e;
}

.overview-controls {
  padding-bottom: 32px;
}

/* Window Picker */
.window-picker {
  spacing: 6px;
}

.window-caption {
  color: #efefef;
  background-color: #22242d;
  border-radius: 3px;
  padding: 6px 12px;
}

.window-close, .screenshot-ui-close-button {
  background-color: #22242d;
  color: #efefef;
  border-radius: 1000px;
  padding: 3px;
  height: 30px;
  width: 30px;
  box-shadow: -1px 1px 5px 0px rgba(0, 0, 0, 0.5);
  transition-duration: 300ms;
  background-image: url("assets/window-close-symbolic.svg");
}

.window-close StIcon, .screenshot-ui-close-button StIcon {
  color: white;
  icon-size: 1px;
}

.window-close:hover, .screenshot-ui-close-button:hover {
  background-color: #424758;
}

.window-close:active, .screenshot-ui-close-button:active {
  color: rgba(239, 239, 239, 0.8);
  background-color: #17181e;
}

.workspace-background {
  border-radius: 30px;
  background-color: #22242d;
  box-shadow: 0 4px 16px 4px rgba(0, 0, 0, 0.3);
}


.search-entry {
  width: 320px;
  padding: 6px 9px;
  border-radius: 18px;
  color: rgba(255, 255, 255, 0.75);
  background-color: rgba(255, 255, 255, 0.1);
  border: 2px solid transparent !important;
  margin-top: 12px;
  margin-bottom: 6px;
}


.search-entry:hover {
  background-color: rgba(255, 255, 255, 0.18);
  border: 2px solid transparent !important;
  color: rgba(255, 255, 255, 0.85);
  padding: 6px 9px;
}


.search-entry:focus {
  background-color: rgba(255, 255, 255, 0.15);
  padding: 6px 9px;
  border: 2px solid #217dbb !important;
  color: rgba(255, 255, 255, 0.85);
  box-shadow: none;
}


.search-entry StLabel.hint-text {
  color: rgba(255, 255, 255, 0.55);
}


.search-entry .search-entry-icon {
  icon-size: 16px;
  padding: 0 4px;
  color: inherit;
}

/* Search */
#searchResultsContent {
  max-width: 1024px;
  spacing: 8px;
}

.search-section {
  spacing: 8px;
}

.search-section .search-section-separator {
  height: 0;
  background-color: transparent;
}

.search-section-content {
  background-color: rgba(255, 255, 255, 0.1);
  border-radius: 5px;
  border: none;
  box-shadow: none;
  text-shadow: none;
  color: #efefef;
  padding: 18px;
  spacing: 8px;
}

.list-search-result:focus, .search-provider-icon:focus, .list-search-result:hover, .search-provider-icon:hover, .list-search-result:selected, .search-provider-icon:selected {
  background-color: rgba(255, 255, 255, 0.1);
  transition-duration: 200ms;
}

.list-search-result:active, .search-provider-icon:active, .list-search-result:checked, .search-provider-icon:checked {
  background-color: rgba(255, 255, 255, 0.15);
}

.grid-search-results {
  spacing: 36px;
}

.search-provider-icon .list-search-provider-content {
  spacing: 12px;
}

.search-provider-icon .list-search-provider-content .list-search-provider-details {
  width: 120px;
  margin-top: 0;
  color: #dbdbdb;
}

.list-search-results {
  spacing: 6px;
}

.list-search-result .list-search-result-content {
  spacing: 6px;
}

.list-search-result .list-search-result-title {
  spacing: 12px;
}

.list-search-result .list-search-result-description {
  color: #a3a3a3;
}

/* Dash */
#dash {
  font-size: 9pt;
  margin-top: 18px;
  padding: 0 10px;
}

#dash .placeholder {
  background-image: none;
  background-size: contain;
  height: 32px;
}

#dash .empty-dash-drop-target {
  width: 32px;
  height: 32px;
}

#dash .overview-icon {
  padding: 5px;
}

.dash-background {
  background-color: rgba(255, 255, 255, 0.1);
  margin-bottom: 16px;
  padding: 10px;
  border-radius: 13px;
}

.dash-item-container .app-well-app, .dash-item-container .show-apps {
  padding: 10px 1.5px 26px;
}

.dash-item-container .show-apps .overview-icon {
  color: #efefef;
}

.dash-item-container .show-apps:hover .overview-icon, .dash-item-container .show-apps:selected .overview-icon {
  background-color: rgba(239, 239, 239, 0.2);
}

.dash-item-container .show-apps:focus .overview-icon {
  background-color: rgba(239, 239, 239, 0.3);
}

.dash-item-container .show-apps:drop .overview-icon {
  border: 2px solid #217dbb;
  background-color: rgba(33, 125, 187, 0.2);
}

.dash-item-container .show-apps:active .overview-icon, .dash-item-container .show-apps:checked .overview-icon {
  background-color: rgba(239, 239, 239, 0.25);
}

.dash-separator {
  width: 1px;
  margin: 0 6.5px 16px;
  background-color: rgba(239, 239, 239, 0.3);
}

.dash-label {
  color: #efefef;
  background-color: #22242d;
  border-radius: 3px;
  padding: 6px 12px;
  text-align: center;
  margin: 6px;
  -y-offset: 12px;
}

/* App Grid */
.icon-grid {
  row-spacing: 12px;
  column-spacing: 12px;
  max-row-spacing: 72px;
  max-column-spacing: 72px;
  page-padding-top: 24px;
  page-padding-bottom: 24px;
  page-padding-left: 12px;
  page-padding-right: 12px;
}

/* App Icons */
.app-well-app .overview-icon,
.grid-search-result .overview-icon {
  color: #ffffff;
}

.app-well-app:hover .overview-icon, .app-well-app:selected .overview-icon,
.grid-search-result:hover .overview-icon,
.grid-search-result:selected .overview-icon {
  background-color: rgba(255, 255, 255, 0.2);
}

.app-well-app:focus .overview-icon,
.grid-search-result:focus .overview-icon {
  background-color: rgba(255, 255, 255, 0.3);
}

.app-well-app:drop .overview-icon,
.grid-search-result:drop .overview-icon {
  border: 2px solid #217dbb;
  background-color: rgba(33, 125, 187, 0.2);
}

.app-well-app:active .overview-icon, .app-well-app:checked .overview-icon,
.grid-search-result:active .overview-icon,
.grid-search-result:checked .overview-icon {
  background-color: rgba(255, 255, 255, 0.25);
}

.app-well-app .overview-icon.overview-icon-with-label,
.grid-search-result .overview-icon.overview-icon-with-label {
  padding: 10px 8px 5px 8px;
}

.app-well-app .overview-icon.overview-icon-with-label > StBoxLayout,
.grid-search-result .overview-icon.overview-icon-with-label > StBoxLayout {
  spacing: 6px;
}

.icon-grid .overview-icon {
  border-radius: 6px;
}

/* App Folders */
.app-well-app.app-folder {
  background-color: transparent !important;
  border-radius: 6px;
}

.app-well-app.app-folder .overview-icon {
  background-color: rgba(255, 255, 255, 0.1);
}

.app-well-app.app-folder .overview-icon {
  color: #ffffff;
}

.app-well-app.app-folder:hover .overview-icon, .app-well-app.app-folder:selected .overview-icon {
  background-color: rgba(255, 255, 255, 0.2);
}

.app-well-app.app-folder:focus .overview-icon {
  background-color: rgba(255, 255, 255, 0.3);
}

.app-well-app.app-folder:drop .overview-icon {
  border: 2px solid #217dbb;
  background-color: rgba(33, 125, 187, 0.2);
}

.app-well-app.app-folder:active .overview-icon, .app-well-app.app-folder:checked .overview-icon {
  background-color: rgba(255, 255, 255, 0.25);
}

.app-folder-dialog {
  border-radius: 7.5px;
  background-color: #17181e;
  padding: 8px !important;
  box-shadow: none;
  outline: none;
}

.app-folder-dialog .folder-name-container {
  padding: 24px 36px 0;
  spacing: 12px;
  /* FIXME: this is to keep the label in sync with the entry */
}

.app-folder-dialog .folder-name-container .folder-name-label,
.app-folder-dialog .folder-name-container .folder-name-entry {
  font-size: 18pt;
  font-weight: 800;
}

.app-folder-dialog .folder-name-container .folder-name-entry {
  width: 300px;
  box-shadow: none;
  border-radius: 1000px;
  border: 2px solid transparent;
  background-color: rgba(247, 247, 247, 0.1);
  color: #efefef;
}

.app-folder-dialog .folder-name-container .folder-name-entry:hover, .app-folder-dialog .folder-name-container .folder-name-entry:focus {
  background-color: rgba(247, 247, 247, 0.1);
  color: rgba(255, 255, 255, 0.75);
  border-color: #217dbb;
  box-shadow: none;
}

.app-folder-dialog .folder-name-container .folder-name-label {
  padding: 5px 7px;
  color: #efefef;
}

.app-folder-dialog .folder-name-container .edit-folder-button {
  border: none;
  box-shadow: none;
  background-color: rgba(255, 255, 255, 0.1);
  color: rgba(255, 255, 255, 0.75);
  padding: 0;
  width: 36px;
  height: 36px;
  border-radius: 18px;
}

.app-folder-dialog .folder-name-container .edit-folder-button:hover {
  background-color: rgba(255, 255, 255, 0.15);
}

.app-folder-dialog .folder-name-container .edit-folder-button:active {
  background-color: rgba(255, 255, 255, 0.2);
}

.app-folder-dialog .folder-name-container .edit-folder-button > StIcon {
  icon-size: 16px;
}

.app-folder-dialog .icon-grid {
  row-spacing: 12px;
  column-spacing: 30px;
  page-padding-top: 0;
  page-padding-bottom: 0;
  page-padding-left: 0;
  page-padding-right: 0;
}

.app-folder-dialog .page-indicators {
  margin-bottom: 18px;
}

.app-folder-dialog-container {
  padding: 12px;
  width: 620px;
  height: 620px;
}

.app-well-app-running-dot {
  height: 5px;
  width: 5px;
  border-radius: 100px;
  background-color: #efefef;
  margin-bottom: 1px;
}

.rename-folder-popup .rename-folder-popup-item {
  spacing: 6px;
}

.rename-folder-popup .rename-folder-popup-item:ltr, .rename-folder-popup .rename-folder-popup-item:rtl {
  padding: 0 12px;
}

.app-menu,
.app-well-menu {
  max-width: 27.25em;
}

.page-indicator {
  padding: 6px 12px 0;
}

.page-indicator .page-indicator-icon {
  width: 10px;
  height: 10px;
  border-radius: 100px;
  background-color: white;
}

.apps-scroll-view {
  padding: 0;
}

.system-action-icon {
  background-color: rgba(221, 221, 221, 0.1);
  color: #dddddd;
  border-radius: 1000px;
  icon-size: 48px;
  border: none;
}

.page-navigation-hint {
  width: 300px;
}

.page-navigation-hint.dnd {
  background: rgba(255, 255, 255, 0.1);
}

.page-navigation-hint.next:ltr, .page-navigation-hint.previous:rtl {
  background-gradient-start: rgba(255, 255, 255, 0.05);
  background-gradient-end: transparent;
  background-gradient-direction: horizontal;
  border-radius: 15px 0px 0px 15px;
}

.page-navigation-hint.previous:ltr, .page-navigation-hint.next:rtl {
  background-gradient-start: transparent;
  background-gradient-end: rgba(255, 255, 255, 0.05);
  background-gradient-direction: horizontal;
  border-radius: 0px 15px 15px 0px;
}

.page-navigation-arrow {
  color: #efefef;
}

.page-navigation-arrow > StIcon {
  margin: 6px;
  padding: 18px;
  width: 24px;
  height: 24px;
  border-radius: 1000px;
  color: rgba(239, 239, 239, 0.75);
}

.page-navigation-arrow:insensitive > StIcon {
  color: #66686e;
  border-color: #14161b;
  background-color: #22242d;
  box-shadow: none;
  text-shadow: none;
  icon-shadow: none;
}

.page-navigation-arrow:hover > StIcon {
  color: #efefef;
  background-color: rgba(62, 64, 71, 0.525);
  border-color: #101115;
  box-shadow: none;
  text-shadow: none;
  icon-shadow: none;
}

.page-navigation-arrow:active > StIcon {
  color: #efefef;
  background-color: rgba(85, 87, 93, 0.55);
  border-color: #101115;
  text-shadow: none;
  icon-shadow: none;
  box-shadow: none;
}

/* Workspace pager */
.workspace-thumbnails {
  visible-width: 32px;
  spacing: 6px;
  padding: 6px;
}

.workspace-thumbnails .workspace-thumbnail {
  border-radius: 3px;
}

.workspace-thumbnails .placeholder {
  background-image: url("resource:///org/gnome/shell/theme/dash-placeholder.svg");
  background-size: contain;
  width: 18px;
}

.workspace-thumbnail-indicator {
  border: 3px solid #217dbb;
  border-radius: 3px;
  padding: 0px;
}

.ripple-pointer-location {
  width: 50px;
  height: 50px;
  border-radius: 25px;
  background-color: rgba(139, 196, 234, 0.3);
  box-shadow: 0 0 2px 2px #5faee3;
}

.pie-timer {
  width: 60px;
  height: 60px;
  -pie-border-width: 3px;
  -pie-border-color: #217dbb;
  -pie-background-color: rgba(182, 218, 242, 0.3);
}

.magnifier-zoom-region {
  border: 2px solid #217dbb;
}

.magnifier-zoom-region.full-screen {
  border-width: 0;
}

.select-area-rubberband {
  background-color: rgba(33, 125, 187, 0.3);
  border: 1px solid #217dbb;
}

.user-icon {
  background-size: contain;
  color: #efefef;
  border-radius: 99px;
  icon-size: 64px;
}

.user-icon:hover {
  color: white;
}

.user-icon StIcon {
  background-color: rgba(239, 239, 239, 0.05);
  border-radius: 99px;
  padding: 12px;
  width: 40px;
  height: 40px;
}

.user-icon.user-avatar {
  border: 2px #efefef;
}

.user-widget.vertical .user-icon {
  icon-size: 96px;
}

.user-widget.vertical .user-icon StIcon {
  padding: 20px;
  padding-top: 18px;
  padding-bottom: 22px;
  width: 88px;
  height: 88px;
}

.lightbox {
  background-color: black;
}

.flashspot {
  background-color: white;
}

.hidden {
  color: rgba(0, 0, 0, 0);
}

.caps-lock-warning-label {
  text-align: center;
  padding-bottom: 8px;
  font-size: 10pt;
  color: #f57900;
}

/* Workspace animation */
.workspace-animation {
  background-color: #17181e;
}

/* Tiled window previews */
.tile-preview {
  background-color: rgba(33, 125, 187, 0.5);
  border: 1px solid #217dbb;
}

.tile-preview-left.on-primary {
  border-radius: 4px 0 0 0;
}

.tile-preview-right.on-primary {
  border-radius: 0 4px 0 0;
}

.tile-preview-left.tile-preview-right.on-primary {
  border-radius: 4px 4px 0 0;
}

/* On-screen Keyboard */
#keyboard {
  background-color: rgba(20, 22, 27, 0.9);
  box-shadow: inset 0 1px 0 0 rgba(255, 255, 255, 0.16);
}

#keyboard .page-indicator {
  padding: 6px;
}

#keyboard .page-indicator .page-indicator-icon {
  width: 8px;
  height: 8px;
}

.key-container {
  padding: 4px;
  spacing: 4px;
}

.keyboard-key {
  color: #dddddd;
  background-color: #262933;
  border-color: #101115;
  box-shadow: none;
  text-shadow: none;
  icon-shadow: none;
  font-size: 16pt;
  min-height: 1.2em;
  min-width: 1.2em;
  border-width: 1px;
  border-style: solid;
  border-radius: 6px;
}

.keyboard-key:focus {
  color: #dddddd;
  text-shadow: none;
  icon-shadow: none;
  box-shadow: inset 0 0 0 2px rgba(33, 125, 187, 0.35) !important;
}

.keyboard-key:hover, .keyboard-key:checked {
  color: #dddddd;
  background-color: #2f323b;
  border-color: #101115;
  box-shadow: none;
  text-shadow: none;
  icon-shadow: none;
}

.keyboard-key:active {
  color: #dddddd;
  background-color: #383b44;
  border-color: #101115;
  text-shadow: none;
  icon-shadow: none;
  box-shadow: none;
}

.keyboard-key:grayed {
  background-color: #1f222a;
  color: #efefef;
  border-color: rgba(0, 0, 0, 0.7);
}

.keyboard-key.default-key {
  color: #dddddd;
  background-color: #262933;
  border-color: #101115;
  box-shadow: none;
  text-shadow: none;
  icon-shadow: none;
}

.keyboard-key.default-key:hover, .keyboard-key.default-key:checked {
  color: #dddddd;
  background-color: #2f323b;
  border-color: #101115;
  box-shadow: none;
  text-shadow: none;
  icon-shadow: none;
}

.keyboard-key.default-key:active {
  color: #dddddd;
  background-color: #383b44;
  border-color: #101115;
  text-shadow: none;
  icon-shadow: none;
  box-shadow: none;
}

.keyboard-key.enter-key {
  color: #ffffff;
  background-color: #217dbb;
  border-color: #101115;
  box-shadow: none;
  text-shadow: none;
  icon-shadow: none;
}

.keyboard-key.enter-key:hover, .keyboard-key.enter-key:checked {
  color: #dddddd;
  background-color: #2d8ac9;
  border-color: #101115;
  box-shadow: none;
  text-shadow: none;
  icon-shadow: none;
}

.keyboard-key.enter-key:active {
  color: #dddddd;
  background-color: #3382b6;
  border-color: #101115;
  text-shadow: none;
  icon-shadow: none;
  box-shadow: none;
}

.keyboard-key.shift-key-uppercase {
  color: #217dbb;
}

.keyboard-key StIcon {
  icon-size: 1.125em;
}

.keyboard-subkeys {
  color: #efefef;
  -arrow-border-radius: 5px;
  -arrow-background-color: #22242d;
  -arrow-border-width: 1px;
  -arrow-border-color: #353947;
  -arrow-base: 20px;
  -arrow-rise: 10px;
  -boxpointer-gap: 6px;
}

.keyboard-subkeys .keyboard-key {
  color: #dddddd;
  background-color: #262933;
  border-color: #101115;
  box-shadow: none;
  text-shadow: none;
  icon-shadow: none;
  border-radius: 3px;
}

.keyboard-subkeys .keyboard-key:focus {
  color: #dddddd;
  text-shadow: none;
  icon-shadow: none;
  box-shadow: inset 0 0 0 2px rgba(33, 125, 187, 0.35) !important;
}

.keyboard-subkeys .keyboard-key:hover, .keyboard-subkeys .keyboard-key:checked {
  color: #dddddd;
  background-color: #2f323b;
  border-color: #101115;
  box-shadow: none;
  text-shadow: none;
  icon-shadow: none;
}

.keyboard-subkeys .keyboard-key:active {
  color: #dddddd;
  background-color: #383b44;
  border-color: #101115;
  text-shadow: none;
  icon-shadow: none;
  box-shadow: none;
}

.emoji-page .keyboard-key {
  background-color: transparent;
  border: none;
  color: initial;
}

.emoji-panel .keyboard-key:latched {
  border-color: #258cd1;
  background-color: #217dbb;
}

.word-suggestions {
  font-size: 14pt;
  spacing: 12px;
  min-height: 20pt;
}

/* Looking Glass */
#LookingGlassDialog {
  background-color: #22242d;
  spacing: 6px;
  padding: 4px;
  border: 1px solid rgba(239, 239, 239, 0.2);
  border-radius: 3px;
  color: #efefef;
}

#LookingGlassDialog > #Toolbar {
  border: none;
  border-radius: 3px;
  background-color: #22242d;
}

#LookingGlassDialog .labels {
  spacing: 6px;
}

#LookingGlassDialog .notebook-tab {
  -natural-hpadding: 12px;
  -minimum-hpadding: 6px;
  font-weight: bold;
  color: #c9c9c9;
  transition-duration: 100ms;
  padding-left: .3em;
  padding-right: .3em;
  border-bottom-width: 2px;
}

#LookingGlassDialog .notebook-tab:hover {
  color: #efefef;
}

#LookingGlassDialog .notebook-tab:selected {
  border-bottom-width: 2px;
  box-shadow: inset 0 -2px 0 0 #258cd1;
  color: #efefef;
}

#LookingGlassDialog StBoxLayout#EvalBox {
  padding: 4px;
  spacing: 6px;
}

#LookingGlassDialog StBoxLayout#ResultsArea {
  spacing: 6px;
}

.lg-dialog StEntry {
  background-color: rgba(44, 48, 59, 0.6);
  color: #efefef;
  border-color: rgba(239, 239, 239, 0.2);
  min-height: 22px;
  selection-background-color: #217dbb;
  selected-color: #ffffff;
}

.lg-dialog .shell-link {
  color: #5faee3;
}

.lg-dialog .shell-link:hover {
  color: #8bc4ea;
}

.lg-dialog .shell-link:active {
  color: #3498db;
}

.lg-dialog .actor-link {
  color: #ccc;
}

.lg-dialog .actor-link:hover {
  color: white;
}

.lg-dialog .actor-link:active {
  color: #999999;
}

.lg-completions-text {
  font-size: .9em;
  font-style: italic;
}

.lg-obj-inspector-title {
  spacing: 6px;
}

.lg-obj-inspector-button {
  border: 1px solid rgba(0, 0, 0, 0.7);
  padding: 4px;
  border-radius: 3px;
}

.lg-obj-inspector-button:hover {
  border: 1px solid #ffffff;
}

#lookingGlassExtensions {
  padding: 4px;
}

.lg-extensions-list {
  padding: 4px;
  spacing: 6px;
}

.lg-extension {
  border: 1px solid rgba(13, 13, 13, 0.7);
  background-color: #2c303b;
  border-radius: 3px;
  padding: 4px;
}

.lg-extension-name {
  font-weight: bold;
}

.lg-extension-meta {
  spacing: 6px;
}

#LookingGlassPropertyInspector {
  background: #22242d;
  border: 1px solid rgba(0, 0, 0, 0.7);
  border-radius: 3px;
  padding: 6px;
}

/* Login Dialog */
.login-dialog-banner-view {
  padding-top: 24px;
  max-width: 23em;
}

.login-dialog,
.unlock-dialog {
  border: none;
  background-color: transparent;
}

.login-dialog StEntry,
.unlock-dialog StEntry {
  background-color: #101115;
  color: #dddddd;
}

.login-dialog .modal-dialog-button-box,
.unlock-dialog .modal-dialog-button-box {
  spacing: 3px;
}

.login-dialog .modal-dialog-button,
.unlock-dialog .modal-dialog-button {
  padding: 4px 18px;
  box-shadow: 0 1px 3px rgba(0, 0, 0, 0.2);
  background-color: #101115;
  border-color: #101115;
  color: #efefef;
}

.login-dialog .modal-dialog-button:hover, .login-dialog .modal-dialog-button:focus,
.unlock-dialog .modal-dialog-button:hover,
.unlock-dialog .modal-dialog-button:focus {
  background-color: #22242d;
  border-color: #22242d;
}

.login-dialog .modal-dialog-button:active,
.unlock-dialog .modal-dialog-button:active {
  box-shadow: none;
  background-color: #0c0d10;
  border-color: #0c0d10;
}

.login-dialog .modal-dialog-button:insensitive,
.unlock-dialog .modal-dialog-button:insensitive {
  color: #66686e;
  border-color: #14161b;
  background-color: #22242d;
  box-shadow: none;
  text-shadow: none;
  icon-shadow: none;
  border-color: #0c0d10;
  background-color: #0c0d10;
  color: rgba(239, 239, 239, 0.7);
}

.login-dialog .modal-dialog-button:default,
.unlock-dialog .modal-dialog-button:default {
  color: #ffffff;
  background-color: #217dbb;
  border-color: #101115;
  box-shadow: none;
  text-shadow: none;
  icon-shadow: none;
  border-color: #217dbb;
}

.login-dialog .modal-dialog-button:default:hover, .login-dialog .modal-dialog-button:default:focus,
.unlock-dialog .modal-dialog-button:default:hover,
.unlock-dialog .modal-dialog-button:default:focus {
  color: #ffffff;
  background-color: #2c84be;
  border-color: #101115;
  box-shadow: none;
  text-shadow: none;
  icon-shadow: none;
  background-color: #258cd1;
  border-color: #258cd1;
}

.login-dialog .modal-dialog-button:default:active,
.unlock-dialog .modal-dialog-button:default:active {
  color: #ffffff;
  background-color: #378ac2;
  border-color: #101115;
  text-shadow: none;
  icon-shadow: none;
  box-shadow: none;
  background-color: #1d6fa5;
  border-color: #1d6fa5;
}

.login-dialog .modal-dialog-button:default:insensitive,
.unlock-dialog .modal-dialog-button:default:insensitive {
  color: #66686e;
  border-color: #14161b;
  background-color: #22242d;
  box-shadow: none;
  text-shadow: none;
  icon-shadow: none;
  border-color: #196090;
  background-color: #196090;
  color: rgba(255, 255, 255, 0.7);
}

.login-dialog .cancel-button,
.login-dialog .switch-user-button,
.login-dialog .login-dialog-session-list-button,
.unlock-dialog .cancel-button,
.unlock-dialog .switch-user-button,
.unlock-dialog .login-dialog-session-list-button {
  padding: 0;
  border-radius: 99px;
  width: 32px;
  height: 32px;
  border-color: #101115;
  background-color: #101115;
}

.login-dialog .cancel-button StIcon,
.login-dialog .switch-user-button StIcon,
.login-dialog .login-dialog-session-list-button StIcon,
.unlock-dialog .cancel-button StIcon,
.unlock-dialog .switch-user-button StIcon,
.unlock-dialog .login-dialog-session-list-button StIcon {
  icon-size: 16px;
}

.login-dialog .caps-lock-warning-label,
.login-dialog .login-dialog-message-warning,
.unlock-dialog .caps-lock-warning-label,
.unlock-dialog .login-dialog-message-warning {
  color: #efefef;
}

.login-dialog-logo-bin {
  padding: 24px 0px;
}

.login-dialog-banner {
  color: #d6d6d6;
}

.login-dialog-button-box {
  width: 23em;
  spacing: 5px;
}

.login-dialog-message {
  text-align: center;
}

.login-dialog-user-selection-box {
  padding: 100px 0px;
}

.login-dialog-not-listed-label {
  padding-left: 2px;
}

.login-dialog-not-listed-button:focus .login-dialog-not-listed-label, .login-dialog-not-listed-button:hover .login-dialog-not-listed-label {
  color: #efefef;
}

.login-dialog-not-listed-label {
  font-size: 10pt;
  font-weight: bold;
  color: #a3a3a3;
  padding-top: 1em;
}

.login-dialog-user-list-view {
  -st-vfade-offset: 1em;
}

.login-dialog-user-list {
  spacing: 12px;
  width: 23em;
}

.login-dialog-user-list:expanded .login-dialog-user-list-item:selected {
  background-color: #217dbb;
  color: #ffffff;
}

.login-dialog-user-list:expanded .login-dialog-user-list-item:logged-in {
  border-right: 2px solid #217dbb;
}

.login-dialog-user-list-item {
  border-radius: 7px;
  padding: 6px;
  color: #a3a3a3;
}

.login-dialog-user-list-item:ltr .user-widget {
  padding-right: 1em;
}

.login-dialog-user-list-item:rtl .user-widget {
  padding-left: 1em;
}

.login-dialog-user-list-item .login-dialog-timed-login-indicator {
  height: 2px;
  margin-top: 6px;
  background-color: #efefef;
}

.login-dialog-user-list-item:focus .login-dialog-timed-login-indicator {
  background-color: #ffffff;
}

.user-widget-label {
  color: #efefef;
}

.user-widget.horizontal .user-widget-label {
  font-size: 13pt;
  font-weight: bold;
  padding-left: 15px;
}

.user-widget.horizontal .user-widget-label:ltr {
  padding-left: 14px;
  text-align: left;
}

.user-widget.horizontal .user-widget-label:rtl {
  padding-right: 14px;
  text-align: right;
}

.user-widget.vertical .user-widget-label {
  font-size: 16pt;
  text-align: center;
  font-weight: normal;
  padding-top: 16px;
}

.login-dialog-prompt-layout {
  padding-top: 24px;
  padding-bottom: 12px;
  spacing: 12px;
  width: 23em;
}

.login-dialog-prompt-entry {
  height: 1.5em;
}

.login-dialog-prompt-label {
  color: #bcbcbc;
  font-size: 12pt;
  padding-top: 1em;
}

/* Screen Shield */
.unlock-dialog-clock {
  color: white;
  font-weight: 300;
  text-align: center;
  spacing: 24px;
  padding-bottom: 2.5em;
}

.unlock-dialog-clock-time {
  font-size: 64pt;
  padding-top: 42px;
  font-feature-settings: "tnum";
}

.unlock-dialog-clock-date {
  font-size: 16pt;
  font-weight: normal;
}

.unlock-dialog-clock-hint {
  font-weight: normal;
  padding-top: 48px;
}

.unlock-dialog-notifications-container {
  margin: 12px 0;
  spacing: 6px;
  width: 23em;
  background-color: transparent;
}

.unlock-dialog-notifications-container .summary-notification-stack-scrollview {
  padding-top: 0;
  padding-bottom: 0;
}

.unlock-dialog-notifications-container .notification,
.unlock-dialog-notifications-container .unlock-dialog-notification-source {
  padding: 12px 6px;
  border: none;
  background-color: rgba(34, 36, 45, 0.3);
  color: #efefef;
  border-radius: 5px;
}

.unlock-dialog-notifications-container .notification.critical,
.unlock-dialog-notifications-container .unlock-dialog-notification-source.critical {
  background-color: rgba(34, 36, 45, 0.9);
}

.unlock-dialog-notification-label {
  padding: 0px 0px 0px 12px;
}

.unlock-dialog-notification-count-text {
  weight: bold;
  padding: 0 6px;
  color: #22242d;
  background-color: rgba(239, 239, 239, 0.3);
  border-radius: 99px;
  margin-right: 12px;
}

.screen-shield-background {
  background: black;
  box-shadow: 0px 2px 4px rgba(0, 0, 0, 0.6);
}

#lockDialogGroup {
  background-color: #17181e;
}

#unlockDialogNotifications StButton#vhandle, #unlockDialogNotifications StButton#hhandle {
  background-color: rgba(38, 41, 51, 0.3);
}

#unlockDialogNotifications StButton#vhandle:hover, #unlockDialogNotifications StButton#vhandle:focus, #unlockDialogNotifications StButton#hhandle:hover, #unlockDialogNotifications StButton#hhandle:focus {
  background-color: rgba(38, 41, 51, 0.5);
}

#unlockDialogNotifications StButton#vhandle:active, #unlockDialogNotifications StButton#hhandle:active {
  background-color: rgba(33, 125, 187, 0.5);
}

.screenshot-ui-show-pointer-button, .screenshot-ui-type-button {
  background-color: transparent;
  border: none;
}

.screenshot-ui-show-pointer-button:hover, .screenshot-ui-type-button:hover {
  background-color: rgba(255, 255, 255, 0.1);
}

.screenshot-ui-show-pointer-button:active, .screenshot-ui-type-button:active {
  background-color: rgba(255, 255, 255, 0.2);
}

.screenshot-ui-show-pointer-button:checked, .screenshot-ui-type-button:checked {
  background-color: rgba(255, 255, 255, 0.15);
}

.icon-label-button-container {
  spacing: 6px;
}

.icon-label-button-container StIcon {
  icon-size: 32px;
}

.screenshot-ui-panel {
  border-radius: 24px;
  padding: 18px;
  margin-bottom: 4em;
  spacing: 12px;
  color: #efefef;
  background-color: #17181e;
  border: 1px solid black;
  box-shadow: 0 3px 8px 0 rgba(0, 0, 0, 0.25);
}

.screenshot-ui-close-button {
  padding: 6px !important;
}

.screenshot-ui-close-button.left {
  margin-left: 8px;
}

.screenshot-ui-close-button.right {
  margin-right: 8px;
}

.screenshot-ui-type-button {
  min-width: 48px;
  padding: 12px 18px !important;
  border-radius: 6px;
}

.screenshot-ui-capture-button {
  width: 36px;
  height: 36px;
  border-radius: 1000px;
  border: 4px white;
  padding: 4px;
}

.screenshot-ui-capture-button .screenshot-ui-capture-button-circle {
  background-color: white;
  transition-duration: 200ms;
  border-radius: 1000px;
}

.screenshot-ui-capture-button .screenshot-ui-capture-button-circle:hover, .screenshot-ui-capture-button .screenshot-ui-capture-button-circle:focus {
  background-color: rgba(221, 221, 221, 0.1);
}

.screenshot-ui-capture-button:hover .screenshot-ui-capture-button-circle, .screenshot-ui-capture-button:focus .screenshot-ui-capture-button-circle {
  background-color: #d9d9d9;
}

.screenshot-ui-capture-button:active .screenshot-ui-capture-button-circle {
  background-color: gray;
}

.screenshot-ui-capture-button:cast .screenshot-ui-capture-button-circle {
  background-color: #ff8080;
}

.screenshot-ui-capture-button:cast:hover .screenshot-ui-capture-button-circle, .screenshot-ui-capture-button:cast:focus .screenshot-ui-capture-button-circle {
  background-color: #ff9a9a;
}

.screenshot-ui-capture-button:cast:active .screenshot-ui-capture-button-circle {
  background-color: #ff5c5c;
}

.screenshot-ui-shot-cast-container {
  background-color: rgba(255, 255, 255, 0.06);
  border-radius: 1000px;
  padding: 3px;
  spacing: 3px;
}

.screenshot-ui-shot-cast-container:ltr {
  margin-left: 0px;
}

.screenshot-ui-shot-cast-container:rtl {
  margin-right: 0px;
}

.screenshot-ui-shot-cast-button {
  padding: 6px 12px;
  background-color: transparent;
  border-radius: 1000px;
}

.screenshot-ui-shot-cast-button:hover, .screenshot-ui-shot-cast-button:focus {
  background-color: rgba(255, 255, 255, 0.1);
}

.screenshot-ui-shot-cast-button:active {
  background-color: rgba(255, 255, 255, 0.2);
}

.screenshot-ui-shot-cast-button:checked {
  background-color: white;
  color: black;
}

.screenshot-ui-shot-cast-button StIcon {
  icon-size: 16px;
}

.screenshot-ui-show-pointer-button {
  border-radius: 1000px;
  padding: 12px !important;
}

.screenshot-ui-show-pointer-button StIcon {
  icon-size: 16px;
}

.screenshot-ui-area-indicator-shade {
  background-color: rgba(0, 0, 0, 0.3);
}

.screenshot-ui-area-selector .screenshot-ui-area-indicator-shade {
  background-color: rgba(0, 0, 0, 0.5);
}

.screenshot-ui-area-selector .screenshot-ui-area-indicator-selection {
  border: 2px white;
}

.screenshot-ui-area-selector-handle {
  border-radius: 1000px;
  background-color: white;
  box-shadow: 0 1px 3px 2px rgba(0, 0, 0, 0.2);
  width: 24px;
  height: 24px;
}

.screenshot-ui-window-selector {
  background-color: #22242d;
}

.screenshot-ui-window-selector .screenshot-ui-window-selector-window-container {
  margin: 100px;
}

.screenshot-ui-window-selector:primary-monitor .screenshot-ui-window-selector-window-container {
  margin-bottom: 200px;
}

.screenshot-ui-window-selector-window-border {
  transition-duration: 200ms;
  border-radius: 3px;
  border: 6px transparent;
}

.screenshot-ui-window-selector-check {
  transition-duration: 200ms;
  color: transparent;
  border-radius: 1000px;
  border-width: 12px;
  icon-size: 24px;
}

.screenshot-ui-window-selector-window:hover .screenshot-ui-window-selector-window-border {
  border-color: #16527a;
}

.screenshot-ui-window-selector-window:checked .screenshot-ui-window-selector-window-border {
  border-color: #217dbb;
  background-color: rgba(33, 125, 187, 0.2);
}

.screenshot-ui-window-selector-window:checked .screenshot-ui-window-selector-check {
  color: white;
  background-color: #217dbb;
}

.screenshot-ui-screen-selector {
  transition-duration: 200ms;
  background-color: rgba(0, 0, 0, 0.5);
}

.screenshot-ui-screen-selector:hover {
  background-color: rgba(0, 0, 0, 0.3);
}

.screenshot-ui-screen-selector:active {
  background-color: rgba(0, 0, 0, 0.7);
}

.screenshot-ui-screen-selector:checked {
  background-color: transparent;
  border: 2px white;
}

.screenshot-ui-tooltip {
  color: #efefef;
  background-color: #22242d;
  border-radius: 1000px;
  padding: 6px 12px;
  text-align: center;
  -y-offset: 24px;
}

.bottom #dashtodockDashScrollview,
.top #dashtodockDashScrollview {
  -st-hfade-offset: 24px;
}

.left #dashtodockDashScrollview,
.right #dashtodockDashScrollview {
  -st-vfade-offset: 24px;
}

#dashtodockContainer {
  background-color: transparent;
}

#dashtodockContainer .dash-item-container {
  background: transparent;
}

#dashtodockContainer .dash-item-container > StWidget {
  background-size: contain;
}

#dashtodockContainer .dash-item-container .app-grid-running-dot {
  margin: 2px !important;
  offset-y: 0 !important;
}

#dashtodockContainer .number-overlay {
  color: white;
  background-color: rgba(0, 0, 0, 0.75);
  text-align: center;
}

#dashtodockContainer .notification-badge {
  color: #ffffff;
  background-color: #217dbb;
  box-shadow: 0 2px 3px 0 rgba(0, 0, 0, 0.25);
  border-radius: 1000px;
  margin: 2px 3px 5px;
  padding: 0.25em 0.6em;
  font-weight: bold;
  text-align: center;
}

#dashtodockContainer.top.straight-corner, #dashtodockContainer.top.straight-corner #dash, #dashtodockContainer.top.shrink.straight-corner, #dashtodockContainer.top.shrink.straight-corner #dash, #dashtodockContainer.top.extended, #dashtodockContainer.top.extended #dash, #dashtodockContainer.top.shrink.extended, #dashtodockContainer.top.shrink.extended #dash {
  margin: 0 !important;
  margin-top: 0 !important;
  padding: 0 !important;
}

#dashtodockContainer.top.straight-corner .dash-background, #dashtodockContainer.top.shrink.straight-corner .dash-background, #dashtodockContainer.top.extended .dash-background, #dashtodockContainer.top.shrink.extended .dash-background {
  margin: 0 !important;
  margin-bottom: 0 !important;
  border-radius: 0;
}

#dashtodockContainer.top.straight-corner .dash-item-container .app-well-app,
#dashtodockContainer.top.straight-corner .overview-tile,
#dashtodockContainer.top.straight-corner .show-apps, #dashtodockContainer.top.shrink.straight-corner .dash-item-container .app-well-app,
#dashtodockContainer.top.shrink.straight-corner .overview-tile,
#dashtodockContainer.top.shrink.straight-corner .show-apps, #dashtodockContainer.top.extended .dash-item-container .app-well-app,
#dashtodockContainer.top.extended .overview-tile,
#dashtodockContainer.top.extended .show-apps, #dashtodockContainer.top.shrink.extended .dash-item-container .app-well-app,
#dashtodockContainer.top.shrink.extended .overview-tile,
#dashtodockContainer.top.shrink.extended .show-apps {
  margin: 0 !important;
}

#dashtodockContainer.bottom.straight-corner, #dashtodockContainer.bottom.straight-corner #dash, #dashtodockContainer.bottom.shrink.straight-corner, #dashtodockContainer.bottom.shrink.straight-corner #dash, #dashtodockContainer.bottom.extended, #dashtodockContainer.bottom.extended #dash, #dashtodockContainer.bottom.shrink.extended, #dashtodockContainer.bottom.shrink.extended #dash {
  margin: 0 !important;
  margin-top: 0 !important;
  padding: 0 !important;
}

#dashtodockContainer.bottom.straight-corner .dash-background, #dashtodockContainer.bottom.shrink.straight-corner .dash-background, #dashtodockContainer.bottom.extended .dash-background, #dashtodockContainer.bottom.shrink.extended .dash-background {
  margin: 0 !important;
  margin-bottom: 0 !important;
  border-radius: 0;
}

#dashtodockContainer.bottom.straight-corner .dash-item-container .app-well-app,
#dashtodockContainer.bottom.straight-corner .overview-tile,
#dashtodockContainer.bottom.straight-corner .show-apps, #dashtodockContainer.bottom.shrink.straight-corner .dash-item-container .app-well-app,
#dashtodockContainer.bottom.shrink.straight-corner .overview-tile,
#dashtodockContainer.bottom.shrink.straight-corner .show-apps, #dashtodockContainer.bottom.extended .dash-item-container .app-well-app,
#dashtodockContainer.bottom.extended .overview-tile,
#dashtodockContainer.bottom.extended .show-apps, #dashtodockContainer.bottom.shrink.extended .dash-item-container .app-well-app,
#dashtodockContainer.bottom.shrink.extended .overview-tile,
#dashtodockContainer.bottom.shrink.extended .show-apps {
  margin: 0 !important;
}

#dashtodockContainer.left.straight-corner, #dashtodockContainer.left.straight-corner #dash, #dashtodockContainer.left.shrink.straight-corner, #dashtodockContainer.left.shrink.straight-corner #dash, #dashtodockContainer.left.extended, #dashtodockContainer.left.extended #dash, #dashtodockContainer.left.shrink.extended, #dashtodockContainer.left.shrink.extended #dash {
  margin: 0 !important;
  margin-top: 0 !important;
  padding: 0 !important;
}

#dashtodockContainer.left.straight-corner .dash-background, #dashtodockContainer.left.shrink.straight-corner .dash-background, #dashtodockContainer.left.extended .dash-background, #dashtodockContainer.left.shrink.extended .dash-background {
  margin: 0 !important;
  margin-bottom: 0 !important;
  border-radius: 0;
}

#dashtodockContainer.left.straight-corner .dash-item-container .app-well-app,
#dashtodockContainer.left.straight-corner .overview-tile,
#dashtodockContainer.left.straight-corner .show-apps, #dashtodockContainer.left.shrink.straight-corner .dash-item-container .app-well-app,
#dashtodockContainer.left.shrink.straight-corner .overview-tile,
#dashtodockContainer.left.shrink.straight-corner .show-apps, #dashtodockContainer.left.extended .dash-item-container .app-well-app,
#dashtodockContainer.left.extended .overview-tile,
#dashtodockContainer.left.extended .show-apps, #dashtodockContainer.left.shrink.extended .dash-item-container .app-well-app,
#dashtodockContainer.left.shrink.extended .overview-tile,
#dashtodockContainer.left.shrink.extended .show-apps {
  margin: 0 !important;
}

#dashtodockContainer.right.straight-corner, #dashtodockContainer.right.straight-corner #dash, #dashtodockContainer.right.shrink.straight-corner, #dashtodockContainer.right.shrink.straight-corner #dash, #dashtodockContainer.right.extended, #dashtodockContainer.right.extended #dash, #dashtodockContainer.right.shrink.extended, #dashtodockContainer.right.shrink.extended #dash {
  margin: 0 !important;
  margin-top: 0 !important;
  padding: 0 !important;
}

#dashtodockContainer.right.straight-corner .dash-background, #dashtodockContainer.right.shrink.straight-corner .dash-background, #dashtodockContainer.right.extended .dash-background, #dashtodockContainer.right.shrink.extended .dash-background {
  margin: 0 !important;
  margin-bottom: 0 !important;
  border-radius: 0;
}

#dashtodockContainer.right.straight-corner .dash-item-container .app-well-app,
#dashtodockContainer.right.straight-corner .overview-tile,
#dashtodockContainer.right.straight-corner .show-apps, #dashtodockContainer.right.shrink.straight-corner .dash-item-container .app-well-app,
#dashtodockContainer.right.shrink.straight-corner .overview-tile,
#dashtodockContainer.right.shrink.straight-corner .show-apps, #dashtodockContainer.right.extended .dash-item-container .app-well-app,
#dashtodockContainer.right.extended .overview-tile,
#dashtodockContainer.right.extended .show-apps, #dashtodockContainer.right.shrink.extended .dash-item-container .app-well-app,
#dashtodockContainer.right.shrink.extended .overview-tile,
#dashtodockContainer.right.shrink.extended .show-apps {
  margin: 0 !important;
}

#dashtodockContainer.extended .dash-background, #dashtodockContainer.straight-corner .dash-background {
  border-radius: 0;
}

#dashtodockContainer.shrink .dash-background {
  border-radius: 6px;
}

#dashtodockContainer.shrink .dash-item-container .app-well-app,
#dashtodockContainer.shrink .overview-tile,
#dashtodockContainer.shrink .show-apps {
  margin: 0 !important;
}

#dashtodockContainer.shrink.extended .dash-background {
  border-radius: 0;
}

#dashtodockContainer.left .dash-item-container .app-well-app, #dashtodockContainer.left .show-apps, #dashtodockContainer.right .dash-item-container .app-well-app, #dashtodockContainer.right .show-apps {
  padding: 1.5px 6px !important;
}

#dashtodockContainer.left .dash-background, #dashtodockContainer.right .dash-background {
  margin-bottom: 0 !important;
}

#dashtodockContainer.left.shrink .dash-background, #dashtodockContainer.left.shrink.extended .dash-background, #dashtodockContainer.right.shrink .dash-background, #dashtodockContainer.right.shrink.extended .dash-background {
  padding: 2px 4px !important;
}

#dashtodockContainer.left.shrink .dash-item-container .app-well-app,
#dashtodockContainer.left.shrink .overview-tile,
#dashtodockContainer.left.shrink .show-apps, #dashtodockContainer.left.shrink.extended .dash-item-container .app-well-app,
#dashtodockContainer.left.shrink.extended .overview-tile,
#dashtodockContainer.left.shrink.extended .show-apps, #dashtodockContainer.right.shrink .dash-item-container .app-well-app,
#dashtodockContainer.right.shrink .overview-tile,
#dashtodockContainer.right.shrink .show-apps, #dashtodockContainer.right.shrink.extended .dash-item-container .app-well-app,
#dashtodockContainer.right.shrink.extended .overview-tile,
#dashtodockContainer.right.shrink.extended .show-apps {
  margin: 0 !important;
  padding: 2px 0 !important;
}

#dashtodockContainer.left.extended .dash-item-container .app-well-app, #dashtodockContainer.left.extended .overview-tile, #dashtodockContainer.left.straight-corner .dash-item-container .app-well-app, #dashtodockContainer.left.straight-corner .overview-tile, #dashtodockContainer.right.extended .dash-item-container .app-well-app, #dashtodockContainer.right.extended .overview-tile, #dashtodockContainer.right.straight-corner .dash-item-container .app-well-app, #dashtodockContainer.right.straight-corner .overview-tile {
  padding: 1.5px 10px !important;
}

#dashtodockContainer.left.extended .show-apps, #dashtodockContainer.left.straight-corner .show-apps, #dashtodockContainer.right.extended .show-apps, #dashtodockContainer.right.straight-corner .show-apps {
  padding: 1.5px 10px 20px !important;
}

#dashtodockContainer.top .dash-background, #dashtodockContainer.bottom .dash-background {
  padding: 10px 8.5px !important;
}

#dashtodockContainer.top.shrink .dash-background, #dashtodockContainer.bottom.shrink .dash-background {
  padding: 4px 2px !important;
}

#dashtodockContainer.top.shrink .dash-item-container .app-well-app,
#dashtodockContainer.top.shrink .overview-tile,
#dashtodockContainer.top.shrink .show-apps, #dashtodockContainer.bottom.shrink .dash-item-container .app-well-app,
#dashtodockContainer.bottom.shrink .overview-tile,
#dashtodockContainer.bottom.shrink .show-apps {
  margin: 0 !important;
  padding: 0 2px 12px !important;
}

#dashtodockContainer.top.extended .dash-separator, #dashtodockContainer.top.straight-corner .dash-separator, #dashtodockContainer.bottom.extended .dash-separator, #dashtodockContainer.bottom.straight-corner .dash-separator {
  margin: 0 6.5px !important;
}

#dashtodockContainer.top.extended .dash-item-container .app-well-app,
#dashtodockContainer.top.extended .overview-tile,
#dashtodockContainer.top.extended .show-apps, #dashtodockContainer.top.straight-corner .dash-item-container .app-well-app,
#dashtodockContainer.top.straight-corner .overview-tile,
#dashtodockContainer.top.straight-corner .show-apps, #dashtodockContainer.bottom.extended .dash-item-container .app-well-app,
#dashtodockContainer.bottom.extended .overview-tile,
#dashtodockContainer.bottom.extended .show-apps, #dashtodockContainer.bottom.straight-corner .dash-item-container .app-well-app,
#dashtodockContainer.bottom.straight-corner .overview-tile,
#dashtodockContainer.bottom.straight-corner .show-apps {
  padding: 10px 1.5px !important;
}

#dashtodockContainer #dash {
  background: none;
}

#dashtodockContainer #dash .dash-background {
  color: #dddddd;
  background-color: rgba(12, 13, 16, 0.9);
  box-shadow: none !important;
  border: none !important;
}

#dashtodockContainer #dash StWidget.focused .app-grid-running-dot,
#dashtodockContainer #dash StWidget.focused .app-well-app-running-dot {
  background-color: #217dbb;
}

#dashtodockContainer:overview #dash {
  background: none;
}

#dashtodockContainer:overview #dash .dash-background {
  background-color: rgba(255, 255, 255, 0.1);
}

#dashtodockContainer:overview #dash StWidget.focused .app-grid-running-dot,
#dashtodockContainer:overview #dash StWidget.focused .app-well-app-running-dot {
  background-color: #217dbb;
}

#dashtodockContainer.opaque:overview #dash, #dashtodockContainer.transparent:overview #dash {
  background-color: transparent !important;
  box-shadow: none !important;
}

#dashtodockContainer.opaque:overview .dash-background, #dashtodockContainer.transparent:overview .dash-background {
  background-color: transparent !important;
}

#dashtodockContainer.extended:overview #dash, #dashtodockContainer.opaque.extended:overview #dash, #dashtodockContainer.transparent.extended:overview #dash {
  background: none;
}

#dashtodockContainer.running-dots .dash-item-container > StButton, #dashtodockContainer.dashtodock .dash-item-container > StButton {
  transition-duration: 250ms;
  background-size: contain;
}

#dashtodockContainer.shrink .dash-item-container > StButton, #dashtodockContainer.dashtodock .dash-item-container > StButton {
  padding: 1px 2px;
}

#dashtodockContainer.extended .app-well-app .overview-icon,
#dashtodockContainer.extended .show-apps .overview-icon, #dashtodockContainer.extended:overview .app-well-app .overview-icon,
#dashtodockContainer.extended:overview .show-apps .overview-icon {
  border-radius: 2px;
}

#dashtodockContainer .metro .overview-icon {
  border-radius: 0;
}

.dash-label.bottom {
  margin-bottom: 16px !important;
}

.dashtodock-app-well-preview-menu-item {
  padding: 1em 1em 0.5em 1em;
}

#dashtodockPreviewSeparator.popup-separator-menu-item-horizontal {
  width: 1px;
  height: auto;
  border-right-width: 1px;
  margin: 32px 0;
}

.openweather-button, .openweather-button-action, .openweather-menu-button-container, .openweather-button-box {
  border: 1px solid transparent !important;
  background: none;
}

.openweather-provider {
  padding: 0 16px;
  font-weight: 500;
  border: 1px solid transparent !important;
  color: #dddddd;
  background-color: #22242d;
  border-color: #101115;
  box-shadow: none;
  text-shadow: none;
  icon-shadow: none;
}

.openweather-provider:hover {
  color: #dddddd;
  background-color: #2b2d36;
  border-color: #101115;
  box-shadow: none;
  text-shadow: none;
  icon-shadow: none;
}

.openweather-provider:focus {
  color: #dddddd;
  text-shadow: none;
  icon-shadow: none;
  box-shadow: inset 0 0 0 2px rgba(33, 125, 187, 0.35) !important;
}

.openweather-provider:active {
  color: #dddddd;
  background-color: #34373e;
  border-color: #101115;
  text-shadow: none;
  icon-shadow: none;
  box-shadow: none;
}

.openweather-provider:insensitive {
  color: #66686e;
  border-color: #14161b;
  background-color: #22242d;
  box-shadow: none;
  text-shadow: none;
  icon-shadow: none;
}

.openweather-current-icon, .openweather-current-summary, .openweather-current-summarybox {
  background: none;
  color: #dddddd;
  -st-icon-style: symbolic;
}

.openweather-current-databox-values {
  background: none;
  color: #aaaaaa;
}

.openweather-current-databox-captions {
  background: none;
  color: #66686e;
}

.openweather-forecast-icon, .openweather-forecast-summary {
  background: none;
  color: #aaaaaa;
  -st-icon-style: symbolic;
}

.openweather-forecast-day {
  background: none;
  color: #dddddd;
}

.openweather-forecast-temperature {
  background: none;
  color: #aaaaaa;
}

.openweather-sunrise-icon, .openweather-sunset-icon, .openweather-build-icon {
  color: #aaaaaa;
  -st-icon-style: symbolic;
}
